@@ -16,28 +16,30 @@
  */
 package org.apache.phoenix.end2end;
 
-import com.google.common.base.Joiner;
-import com.google.common.base.Throwables;
+import org.apache.phoenix.thirdparty.com.google.common.base.Joiner;
+import org.apache.phoenix.thirdparty.com.google.common.base.Throwables;
 import com.google.protobuf.RpcCallback;
 import com.google.protobuf.RpcController;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.AuthUtil;
 import org.apache.hadoop.hbase.CoprocessorEnvironment;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
-import org.apache.hadoop.hbase.HConstants;
+import org.apache.hadoop.hbase.LocalHBaseCluster;
 import org.apache.hadoop.hbase.NamespaceDescriptor;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.ConnectionFactory;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
 import org.apache.hadoop.hbase.protobuf.ProtobufUtil;
-import org.apache.hadoop.hbase.protobuf.ResponseConverter;
 import org.apache.hadoop.hbase.protobuf.generated.AccessControlProtos;
 import org.apache.hadoop.hbase.security.AccessDeniedException;
 import org.apache.hadoop.hbase.security.User;
 import org.apache.hadoop.hbase.security.access.AccessControlClient;
+import org.apache.hadoop.hbase.security.access.AccessControlUtil;
 import org.apache.hadoop.hbase.security.access.AccessController;
 import org.apache.hadoop.hbase.security.access.Permission;
 import org.apache.hadoop.hbase.security.access.UserPermission;
+import org.apache.hadoop.hbase.shaded.protobuf.ResponseConverter;
+import org.apache.hadoop.hbase.util.VersionInfo;
 import org.apache.phoenix.coprocessor.MetaDataProtocol;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
@@ -50,6 +52,7 @@ import org.apache.phoenix.schema.TableNotFoundException;
 import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.SchemaUtil;
 import org.junit.Before;
+import org.junit.BeforeClass;
 import org.junit.FixMethodOrder;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
@@ -80,6 +83,7 @@ import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
+import static org.junit.Assume.assumeFalse;
 
 @Category(NeedsOwnMiniClusterTest.class)
 @FixMethodOrder(MethodSorters.NAME_ASCENDING)
@@ -150,6 +154,11 @@ public abstract class BasePermissionsIT extends BaseTest {
         this.tableName = generateUniqueName();
     }
 
+    @BeforeClass
+    public static synchronized void skipHBase21() {
+        assumeFalse(VersionInfo.getVersion().startsWith("2.1"));
+    }
+
     static void initCluster(boolean isNamespaceMapped) throws Exception {
         initCluster(isNamespaceMapped, false);
     }
@@ -165,7 +174,8 @@ public abstract class BasePermissionsIT extends BaseTest {
         Configuration config = testUtil.getConfiguration();
         enablePhoenixHBaseAuthorization(config, useCustomAccessController);
         configureNamespacesOnServer(config, isNamespaceMapped);
-        config.setInt(HConstants.MASTER_INFO_PORT, -1);
+        configureStatsConfigurations(config);
+        config.setBoolean(LocalHBaseCluster.ASSIGN_RANDOM_PORTS, true);
 
         testUtil.startMiniCluster(1);
         superUser1 = User.createUserForTesting(config, SUPER_USER, new String[0]);
@@ -416,7 +426,7 @@ public abstract class BasePermissionsIT extends BaseTest {
         return createTable(tableName, NUM_RECORDS);
     }
 
-    AccessTestAction createTable(final String tableName, final int numRecordsToInsert) throws SQLException {
+    AccessTestAction createTable(final String tableName, int numRecordsToInsert) throws SQLException {
         return new AccessTestAction() {
             @Override
             public Object run() throws Exception {
@@ -500,7 +510,7 @@ public abstract class BasePermissionsIT extends BaseTest {
 
     }
 
-    private AccessTestAction readStatsAfterTableDelete(final String physicalTableName) throws SQLException {
+    private AccessTestAction readStatsAfterTableDelete(String physicalTableName) throws SQLException {
         return new AccessTestAction() {
             @Override
             public Object run() throws Exception {
@@ -1006,7 +1016,7 @@ public abstract class BasePermissionsIT extends BaseTest {
             verifyAllowed(createSchema(schemaName), superUser1);
             verifyAllowed(grantPermissions("C", regularUser1, schemaName, true), superUser1);
         } else {
-            verifyAllowed(grantPermissions("C", regularUser1, surroundWithDoubleQuotes(SchemaUtil.SCHEMA_FOR_DEFAULT_NAMESPACE), true), superUser1);
+            verifyAllowed(grantPermissions("C", regularUser1, surroundWithDoubleQuotes(QueryConstants.HBASE_DEFAULT_SCHEMA_NAME), true), superUser1);
         }
 
         // Create new table. Create indexes, views and view indexes on top of it. Verify the contents by querying it
@@ -1090,7 +1100,7 @@ public abstract class BasePermissionsIT extends BaseTest {
             verifyAllowed(createSchema(schemaName), superUser1);
             verifyAllowed(grantPermissions("C", regularUser1, schemaName, true), superUser1);
         } else {
-            verifyAllowed(grantPermissions("C", regularUser1, surroundWithDoubleQuotes(SchemaUtil.SCHEMA_FOR_DEFAULT_NAMESPACE), true), superUser1);
+            verifyAllowed(grantPermissions("C", regularUser1, surroundWithDoubleQuotes(QueryConstants.HBASE_DEFAULT_SCHEMA_NAME), true), superUser1);
         }
 
         // Create MultiTenant Table (View Index Table should be automatically created)
@@ -1136,7 +1146,7 @@ public abstract class BasePermissionsIT extends BaseTest {
             verifyAllowed(grantPermissions("RX", regularUser1, schemaName, true), superUser1);
         } else {
             verifyAllowed(createTable(fullTableName), superUser1);
-            verifyAllowed(grantPermissions("RX", regularUser1, surroundWithDoubleQuotes(SchemaUtil.SCHEMA_FOR_DEFAULT_NAMESPACE), true), superUser1);
+            verifyAllowed(grantPermissions("RX", regularUser1, surroundWithDoubleQuotes(QueryConstants.HBASE_DEFAULT_SCHEMA_NAME), true), superUser1);
         }
         verifyAllowed(createView(view1TableName, fullTableName), regularUser1);
     }
@@ -1444,7 +1454,7 @@ public abstract class BasePermissionsIT extends BaseTest {
             if(env instanceof RegionCoprocessorEnvironment) {
                 aclRegion = AccessControlClient.ACL_TABLE_NAME.
                         equals(((RegionCoprocessorEnvironment) env).getRegion().
-                                getTableDesc().getTableName());
+                                getTableDescriptor().getTableName());
             }
         }
 
@@ -1476,18 +1486,18 @@ public abstract class BasePermissionsIT extends BaseTest {
                             request.hasNamespaceName() ? request.getNamespaceName().toStringUtf8() : null;
                     perms.addAll(AccessControlClient.getUserPermissions(connection, AuthUtil.toGroupEntry(namespace)));
                 }
-                response = ResponseConverter.buildGetUserPermissionsResponse(perms);
+                response = AccessControlUtil.buildGetUserPermissionsResponse(perms);
             } catch (Throwable ioe) {
                 // pass exception back up
                 ResponseConverter.setControllerException(controller, new IOException(ioe));
             }
-            done.run(response);
             if(connection != null) {
                 try {
                     connection.close();
                 } catch (IOException e) {
                 }
             }
+            done.run(response);
         }
     }
 }
