@@ -37,13 +37,14 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Properties;
 
-import org.apache.hadoop.hbase.HColumnDescriptor;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.HTableDescriptor;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
+import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.ipc.PhoenixRpcSchedulerFactory;
 import org.apache.hadoop.hbase.regionserver.BloomType;
-import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.phoenix.exception.SQLExceptionCode;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
@@ -52,7 +53,6 @@ import org.apache.phoenix.query.BaseTest;
 import org.apache.phoenix.query.KeyRange;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.query.QueryServicesOptions;
-import org.apache.phoenix.schema.ColumnAlreadyExistsException;
 import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.schema.PTable.ImmutableStorageScheme;
 import org.apache.phoenix.schema.PTable.QualifierEncodingScheme;
@@ -91,136 +91,6 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
         assertTrue(splits.size() > 0);
     }
 
-    @Test
-    public void testCreateAlterTableWithDuplicateColumn() throws Exception {
-        Properties props = new Properties();
-        int failureCount = 0;
-        int expectedExecCount = 0;
-        String tableName = generateUniqueName();
-        String viewName = generateUniqueName();
-        try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
-            try {
-                // Case 1 - Adding a column as "Default_CF.Column" in
-                // CREATE TABLE query where "Column" is same as single PK Column
-                conn.createStatement().execute(String.format("CREATE TABLE %s"
-                        + " (name VARCHAR NOT NULL PRIMARY KEY, city VARCHAR,"
-                        + " name1 VARCHAR, name VARCHAR)", tableName));
-                fail("Should have failed with ColumnAlreadyExistsException");
-            } catch (ColumnAlreadyExistsException e) {
-                // expected
-                failureCount++;
-            }
-            try {
-                // Case 2 - Adding a column as "Default_CF.Column" in CREATE
-                // TABLE query where "Default_CF.Column" already exists as non-Pk column
-                conn.createStatement().execute(String.format("CREATE TABLE %s"
-                        + " (name VARCHAR NOT NULL PRIMARY KEY, city VARCHAR,"
-                        + " name1 VARCHAR, name1 VARCHAR)", tableName));
-                fail("Should have failed with ColumnAlreadyExistsException");
-            } catch (ColumnAlreadyExistsException e) {
-                // expected
-                failureCount++;
-            }
-            try {
-                // Case 3 - Adding a column as "Default_CF.Column" in CREATE
-                // TABLE query where "Column" is same as single PK Column.
-                // The only diff from Case 1 is that both PK Column and
-                // "Default_CF.Column" are of different DataType
-                conn.createStatement().execute(String.format("CREATE TABLE %s"
-                        + " (key1 VARCHAR NOT NULL PRIMARY KEY, city VARCHAR,"
-                        + " name1 VARCHAR, key1 INTEGER)", tableName));
-                fail("Should have failed with ColumnAlreadyExistsException");
-            } catch (ColumnAlreadyExistsException e) {
-                // expected
-                failureCount++;
-            }
-            try {
-                // Case 4 - Adding a column as "Default_CF.Column" in
-                // CREATE TABLE query where "Column" is same as one of the
-                // PK Column from Composite PK Columns
-                conn.createStatement().execute(String.format("CREATE TABLE %s"
-                        + " (name VARCHAR NOT NULL, name1 VARCHAR NOT NULL,"
-                        + " name2 VARCHAR, name VARCHAR"
-                        + " CONSTRAINT PK PRIMARY KEY(name, name1))", tableName));
-                fail("Should have failed with ColumnAlreadyExistsException");
-            } catch (ColumnAlreadyExistsException e) {
-                // expected
-                failureCount++;
-            }
-            try {
-                // Case 5 - Adding a column as "Default_CF.Column" in
-                // CREATE VIEW query where "Column" is same as one of the
-                // PK Column from Composite PK Columns derived from parent table
-                conn.createStatement().execute(String.format("CREATE TABLE %s"
-                        + " (name VARCHAR NOT NULL, name1 VARCHAR NOT NULL,"
-                        + " name2 VARCHAR, name3 VARCHAR"
-                        + " CONSTRAINT PK PRIMARY KEY(name, name1))", tableName));
-                expectedExecCount++;
-                conn.createStatement().execute(String.format("CREATE VIEW %s"
-                        + " (name1 CHAR(5)) AS SELECT * FROM %s", viewName, tableName));
-                fail("Should have failed with ColumnAlreadyExistsException");
-            } catch (ColumnAlreadyExistsException e) {
-                // expected
-                failureCount++;
-            }
-            try {
-                // Case 6 - Adding a column as "Default_CF.Column" in
-                // ALTER TABLE query where "Column" is same as one of the
-                // PK Column from Composite PK Columns
-                conn.createStatement().execute(
-                        String.format("DROP TABLE %s", tableName));
-                conn.createStatement().execute(String.format("CREATE TABLE %s"
-                        + " (name VARCHAR NOT NULL, name1 VARCHAR NOT NULL,"
-                        + " name2 VARCHAR, name3 VARCHAR"
-                        + " CONSTRAINT PK PRIMARY KEY(name, name1))", tableName));
-                expectedExecCount++;
-                conn.createStatement().execute(
-                        String.format("ALTER TABLE %s ADD name1 INTEGER", tableName));
-                fail("Should have failed with ColumnAlreadyExistsException");
-            } catch (ColumnAlreadyExistsException e) {
-                // expected
-                failureCount++;
-            }
-            try {
-                // Case 7 - Adding a column as "Default_CF.Column" in
-                // ALTER TABLE query where "Column" is same as single PK Column
-                conn.createStatement().execute(
-                        String.format("DROP TABLE %s", tableName));
-                conn.createStatement().execute(String.format("CREATE TABLE %s"
-                        + " (name VARCHAR NOT NULL PRIMARY KEY, city VARCHAR,"
-                        + " name1 VARCHAR, name2 VARCHAR)", tableName));
-                expectedExecCount++;
-                conn.createStatement().execute(
-                        String.format("ALTER TABLE %s ADD name VARCHAR", tableName));
-                fail("Should have failed with ColumnAlreadyExistsException");
-            } catch (ColumnAlreadyExistsException e) {
-                // expected
-                failureCount++;
-            }
-            assertEquals(7, failureCount);
-            assertEquals(3, expectedExecCount);
-
-            conn.createStatement().execute(
-                    String.format("DROP TABLE %s", tableName));
-            // Case 8 - Adding a column as "Non_Default_CF.Column" in
-            // CREATE TABLE query where "Column" is same as single PK Column
-            // Hence, we allow creating such column
-            conn.createStatement().execute(String.format("CREATE TABLE %s"
-                    + " (name VARCHAR NOT NULL PRIMARY KEY, city VARCHAR,"
-                    + " name1 VARCHAR, a.name VARCHAR)", tableName));
-            conn.createStatement().execute(
-                    String.format("DROP TABLE %s", tableName));
-            // Case 9 - Adding a column as "Non_Default_CF.Column" in
-            // ALTER TABLE query where "Column" is same as single PK Column
-            // Hence, we allow creating such column
-            conn.createStatement().execute(String.format("CREATE TABLE %s"
-                    + " (name VARCHAR NOT NULL PRIMARY KEY, city VARCHAR,"
-                    + " name1 VARCHAR, name2 VARCHAR)", tableName));
-            conn.createStatement().execute(
-                    String.format("ALTER TABLE %s ADD a.name VARCHAR", tableName));
-        }
-    }
-
     @Test
     public void testCreateTable() throws Exception {
         String schemaName = "TEST";
@@ -256,10 +126,10 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
         try (Connection conn = DriverManager.getConnection(getUrl(), props);) {
             conn.createStatement().execute(ddl);
         }
-        HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
-        assertNotNull(admin.getTableDescriptor(Bytes.toBytes(tableName)));
-        HColumnDescriptor[] columnFamilies =
-                admin.getTableDescriptor(Bytes.toBytes(tableName)).getColumnFamilies();
+        Admin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
+        assertNotNull(admin.getDescriptor(TableName.valueOf(tableName)));
+        ColumnFamilyDescriptor[] columnFamilies =
+                admin.getDescriptor(TableName.valueOf(tableName)).getColumnFamilies();
         assertEquals(BloomType.NONE, columnFamilies[0].getBloomFilterType());
 
         try (Connection conn = DriverManager.getConnection(getUrl(), props);) {
@@ -278,8 +148,8 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
         }
         try (Connection conn = DriverManager.getConnection(getUrl(), props);) {
             conn.createStatement().execute(ddl);
-            assertNotEquals(null, admin.getTableDescriptor(
-                SchemaUtil.getPhysicalTableName(tableName.getBytes(), true).getName()));
+            assertNotEquals(null, admin.getDescriptor(TableName.valueOf(
+                SchemaUtil.getPhysicalTableName(tableName.getBytes(), true).getName())));
         } finally {
             admin.close();
         }
@@ -327,9 +197,9 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
         Properties props = new Properties();
         Connection conn = DriverManager.getConnection(getUrl(), props);
         conn.createStatement().execute(ddl);
-        HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
-        HColumnDescriptor[] columnFamilies =
-                admin.getTableDescriptor(Bytes.toBytes(tableName)).getColumnFamilies();
+        Admin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
+        ColumnFamilyDescriptor[] columnFamilies =
+                admin.getDescriptor(TableName.valueOf(tableName)).getColumnFamilies();
         assertEquals(1, columnFamilies.length);
         assertEquals(86400, columnFamilies[0].getTimeToLive());
     }
@@ -380,9 +250,9 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
         Properties props = new Properties();
         Connection conn = DriverManager.getConnection(getUrl(), props);
         conn.createStatement().execute(ddl);
-        HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
-        HColumnDescriptor[] columnFamilies =
-                admin.getTableDescriptor(Bytes.toBytes(tableName)).getColumnFamilies();
+        Admin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
+        ColumnFamilyDescriptor[] columnFamilies =
+                admin.getDescriptor(TableName.valueOf(tableName)).getColumnFamilies();
         assertEquals(2, columnFamilies.length);
         assertEquals(86400, columnFamilies[0].getTimeToLive());
         assertEquals("B", columnFamilies[0].getNameAsString());
@@ -406,9 +276,9 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
         Properties props = new Properties();
         Connection conn = DriverManager.getConnection(getUrl(), props);
         conn.createStatement().execute(ddl);
-        HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
-        HColumnDescriptor[] columnFamilies =
-                admin.getTableDescriptor(Bytes.toBytes(tableName)).getColumnFamilies();
+        Admin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
+        ColumnFamilyDescriptor[] columnFamilies =
+                admin.getDescriptor(TableName.valueOf(tableName)).getColumnFamilies();
         assertEquals(2, columnFamilies.length);
         assertEquals("0", columnFamilies[0].getNameAsString());
         assertEquals(86400, columnFamilies[0].getTimeToLive());
@@ -434,12 +304,12 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
         Properties props = new Properties();
         Connection conn = DriverManager.getConnection(getUrl(), props);
         conn.createStatement().execute(ddl);
-        HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
-        HColumnDescriptor[] columnFamilies =
-                admin.getTableDescriptor(Bytes.toBytes(tableName)).getColumnFamilies();
+        Admin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
+        ColumnFamilyDescriptor[] columnFamilies =
+                admin.getDescriptor(TableName.valueOf(tableName)).getColumnFamilies();
         assertEquals(2, columnFamilies.length);
         assertEquals("0", columnFamilies[0].getNameAsString());
-        assertEquals(HColumnDescriptor.DEFAULT_BLOCKSIZE, columnFamilies[0].getBlocksize());
+        assertEquals(ColumnFamilyDescriptorBuilder.DEFAULT_BLOCKSIZE, columnFamilies[0].getBlocksize());
         assertEquals("B", columnFamilies[1].getNameAsString());
         assertEquals(50000, columnFamilies[1].getBlocksize());
     }
@@ -461,9 +331,9 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
         Properties props = new Properties();
         Connection conn = DriverManager.getConnection(getUrl(), props);
         conn.createStatement().execute(ddl);
-        HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
-        HColumnDescriptor[] columnFamilies =
-                admin.getTableDescriptor(Bytes.toBytes(tableName)).getColumnFamilies();
+        Admin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
+        ColumnFamilyDescriptor[] columnFamilies =
+                admin.getDescriptor(TableName.valueOf(tableName)).getColumnFamilies();
         assertEquals(2, columnFamilies.length);
         assertEquals("B", columnFamilies[0].getNameAsString());
         assertEquals(50000, columnFamilies[0].getBlocksize());
@@ -486,9 +356,9 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
         Properties props = new Properties();
         Connection conn = DriverManager.getConnection(getUrl(), props);
         conn.createStatement().execute(ddl);
-        HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
-        HColumnDescriptor[] columnFamilies =
-                admin.getTableDescriptor(Bytes.toBytes(tableName)).getColumnFamilies();
+        Admin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
+        ColumnFamilyDescriptor[] columnFamilies =
+                admin.getDescriptor(TableName.valueOf(tableName)).getColumnFamilies();
         assertEquals(1, columnFamilies.length);
         assertEquals("a", columnFamilies[0].getNameAsString());
         assertEquals(10000, columnFamilies[0].getTimeToLive());
@@ -508,9 +378,9 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
         Properties props = new Properties();
         Connection conn = DriverManager.getConnection(getUrl(), props);
         conn.createStatement().execute(ddl);
-        HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
-        HColumnDescriptor[] columnFamilies =
-                admin.getTableDescriptor(Bytes.toBytes(tableName)).getColumnFamilies();
+        Admin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
+        ColumnFamilyDescriptor[] columnFamilies =
+                admin.getDescriptor(TableName.valueOf(tableName)).getColumnFamilies();
         assertEquals(1, columnFamilies.length);
         assertEquals("a", columnFamilies[0].getNameAsString());
         assertEquals(10000, columnFamilies[0].getTimeToLive());
@@ -527,9 +397,9 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
         Properties props = new Properties();
         Connection conn = DriverManager.getConnection(getUrl(), props);
         conn.createStatement().execute(ddl);
-        HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
-        HColumnDescriptor[] columnFamilies =
-                admin.getTableDescriptor(Bytes.toBytes(tableName)).getColumnFamilies();
+        Admin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
+        ColumnFamilyDescriptor[] columnFamilies =
+                admin.getDescriptor(TableName.valueOf(tableName)).getColumnFamilies();
         assertEquals(BloomType.ROW, columnFamilies[0].getBloomFilterType());
     }
 
@@ -997,7 +867,7 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
     }
 
     @Test
-    public void testSetHTableDescriptorPropertyOnView() throws Exception {
+    public void testSetTableDescriptorPropertyOnView() throws Exception {
         Properties props = new Properties();
         final String dataTableFullName = generateUniqueName();
         String ddl =
@@ -1123,7 +993,7 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
         String fullTableName = SchemaUtil.getTableName(TestUtil.DEFAULT_SCHEMA_NAME, tableName);
         String fullIndexeName = SchemaUtil.getTableName(TestUtil.DEFAULT_SCHEMA_NAME, indexName);
         // Check system tables priorities.
-        try (HBaseAdmin admin = driver.getConnectionQueryServices(null, null).getAdmin(); 
+        try (Admin admin = driver.getConnectionQueryServices(null, null).getAdmin();
                 Connection c = DriverManager.getConnection(getUrl())) {
             ResultSet rs = c.getMetaData().getTables("", 
                     "\""+ PhoenixDatabaseMetaData.SYSTEM_CATALOG_SCHEMA + "\"", 
@@ -1134,7 +1004,7 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
                 String schemaName = rs.getString(PhoenixDatabaseMetaData.TABLE_SCHEM);
                 String tName = rs.getString(PhoenixDatabaseMetaData.TABLE_NAME);
                 org.apache.hadoop.hbase.TableName hbaseTableName = SchemaUtil.getPhysicalTableName(SchemaUtil.getTableName(schemaName, tName), p);
-                HTableDescriptor htd = admin.getTableDescriptor(hbaseTableName);
+                TableDescriptor htd = admin.getDescriptor(hbaseTableName);
                 String val = htd.getValue("PRIORITY");
                 assertNotNull("PRIORITY is not set for table:" + htd, val);
                 assertTrue(Integer.parseInt(val)
@@ -1153,12 +1023,12 @@ public class CreateTableIT extends ParallelStatsDisabledIT {
                 stmt.execute(ddl);
             }
 
-            HTableDescriptor dataTable = admin.getTableDescriptor(
+            TableDescriptor dataTable = admin.getDescriptor(
                     org.apache.hadoop.hbase.TableName.valueOf(fullTableName));
             String val = dataTable.getValue("PRIORITY");
             assertTrue(val == null || Integer.parseInt(val) < HConstants.HIGH_QOS);
 
-            HTableDescriptor indexTable = admin.getTableDescriptor(
+            TableDescriptor indexTable = admin.getDescriptor(
                     org.apache.hadoop.hbase.TableName.valueOf(fullIndexeName));
             val = indexTable.getValue("PRIORITY");
             assertNotNull("PRIORITY is not set for table:" + indexTable, val);
