@@ -32,7 +32,8 @@ import java.sql.SQLException;
 import java.util.Collections;
 import java.util.List;
 
-import org.apache.hadoop.hbase.client.HBaseAdmin;
+import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.Admin;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.jdbc.PhoenixResultSet;
@@ -49,7 +50,7 @@ import org.apache.phoenix.util.PhoenixRuntime;
 import org.junit.BeforeClass;
 import org.junit.Test;
 
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 /**
  * This class has tests for asserting the bytes and rows information exposed in the explain plan
@@ -479,9 +480,9 @@ public class ExplainPlanWithStatsEnabledIT extends ParallelStatsEnabledIT {
         String tenant3 = "tenant3";
         String tenant4 = "tenant4";
         MyClock clock = new MyClock(1000);
+        
         createMultitenantTableAndViews(tenant1View, tenant2View, tenant3View, tenant4View, tenant1, tenant2,
             tenant3, tenant4, multiTenantBaseTable, clock);
-
         // query the entire multitenant table
         String sql = "SELECT * FROM " + multiTenantBaseTable + " WHERE ORGID >= ?";
         List<Object> binds = Lists.newArrayList();
@@ -530,6 +531,7 @@ public class ExplainPlanWithStatsEnabledIT extends ParallelStatsEnabledIT {
             // Update tenant1 view
             try (Connection conn = getTenantConnection(tenant2)) {
                 // upsert a few rows for tenantView
+                clock.setAdvance(false);
                 conn.createStatement()
                         .executeUpdate("UPSERT INTO " + tenant2View + " VALUES (11, 11, 11)");
                 conn.createStatement()
@@ -924,6 +926,7 @@ public class ExplainPlanWithStatsEnabledIT extends ParallelStatsEnabledIT {
                     "upsert into " + multiTenantTable + " values ('" + tenant3 + "',6,10,10)");
                 conn.commit();
             }
+            clock.setAdvance(false);
             try (Connection conn = getTenantConnection(tenant1)) {
                 conn.createStatement().execute(
                     "CREATE VIEW " + tenant1View + " AS SELECT * FROM " + multiTenantTable);
@@ -950,6 +953,7 @@ public class ExplainPlanWithStatsEnabledIT extends ParallelStatsEnabledIT {
 
     private static class MyClock extends EnvironmentEdge {
         public volatile long time;
+        private boolean shouldAdvance = true;
 
         public MyClock(long time) {
             this.time = time;
@@ -957,9 +961,15 @@ public class ExplainPlanWithStatsEnabledIT extends ParallelStatsEnabledIT {
 
         @Override
         public long currentTime() {
-            return time;
+            if(shouldAdvance) {
+                return time++;
+            } else {
+                return time;
+            }
+        }
+        public void setAdvance(boolean val) {
+            shouldAdvance = val;
         }
-
         public void advanceTime(long t) {
             this.time += t;
         }
@@ -980,10 +990,10 @@ public class ExplainPlanWithStatsEnabledIT extends ParallelStatsEnabledIT {
         createTestTable(getUrl(), ddl, null, null);
         try (Connection conn = DriverManager.getConnection(getUrl())) {
             // split such that some data for view2 resides on region of view1
-            try (HBaseAdmin admin =
+            try (Admin admin =
                     conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
                 byte[] splitKey = Bytes.toBytes("00Dabcdetenant200B");
-                admin.split(Bytes.toBytes(multiTenantTable), splitKey);
+                admin.split(TableName.valueOf(multiTenantTable), splitKey);
             }
 
             /**
