@@ -84,7 +84,6 @@ public class MutationStateIT extends ParallelStatsDisabledIT {
         }
     }
 
-
     public static String randString(int length) {
         return new BigInteger(164, RAND).toString().substring(0, length);
     }
@@ -144,7 +143,7 @@ public class MutationStateIT extends ParallelStatsDisabledIT {
     }
 
     @Test
-    @Repeat(5)
+    @Repeat(10)
     public void testOnlyIndexTableWriteFromClientSide()
             throws SQLException, InterruptedException, IOException {
         String schemaName = generateUniqueName();
@@ -302,6 +301,7 @@ public class MutationStateIT extends ParallelStatsDisabledIT {
                     assertTrue(dataTableRows > rowCountIndex);
                 }
             }
+
         } catch (InterruptedException e) {
             throw e;
         } catch (IOException e) {
@@ -534,7 +534,7 @@ public class MutationStateIT extends ParallelStatsDisabledIT {
             conn.createStatement().execute(ddl);
         }
     }
-    
+
     @Test
     public void testNoPendingMutationsOnDDL() throws Exception {
         Properties props = new Properties();
@@ -547,7 +547,7 @@ public class MutationStateIT extends ParallelStatsDisabledIT {
             conn.createStatement().execute(ddl);
             // ensure table got created
             Admin admin = driver.getConnectionQueryServices(getUrl(), props).getAdmin();
-            assertNotNull(admin.getTableDescriptor(TableName.valueOf(tableName)));
+            assertNotNull(admin.getDescriptor(TableName.valueOf(tableName)));
             assertNotNull(PhoenixRuntime.getTableNoCache(conn, tableName));
         }
     }
@@ -566,7 +566,7 @@ public class MutationStateIT extends ParallelStatsDisabledIT {
         Properties connectionProperties = new Properties();
         connectionProperties.setProperty(QueryServices.HBASE_CLIENT_KEYVALUE_MAXSIZE, "20");
         try (PhoenixConnection connection =
-                (PhoenixConnection) DriverManager.getConnection(getUrl(), connectionProperties)) {
+                     (PhoenixConnection) DriverManager.getConnection(getUrl(), connectionProperties)) {
             String fullTableName = generateUniqueName();
             String pk1Name = generateUniqueName();
             String pk2Name = generateUniqueName();
