@@ -33,7 +33,6 @@ import java.sql.DriverManager;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
-import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 
@@ -41,27 +40,26 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.FileUtil;
 import org.apache.hadoop.fs.Path;
-import org.apache.hadoop.hbase.HColumnDescriptor;
-import org.apache.hadoop.hbase.HRegionInfo;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.TableName;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
-import org.apache.hadoop.hbase.client.HTable;
-import org.apache.hadoop.hbase.client.HTableInterface;
+import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
+import org.apache.hadoop.hbase.client.ConnectionFactory;
+import org.apache.hadoop.hbase.client.RegionInfo;
+import org.apache.hadoop.hbase.client.RegionLocator;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
+import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.util.Bytes;
-import org.apache.hadoop.hbase.util.FSUtils;
+import org.apache.hadoop.hbase.util.CommonFSUtils;
 import org.apache.hadoop.hbase.util.Pair;
-import org.apache.phoenix.compile.ExplainPlan;
-import org.apache.phoenix.compile.ExplainPlanAttributes;
 import org.apache.phoenix.compile.QueryPlan;
 import org.apache.phoenix.coprocessor.BaseScannerRegionObserver;
 import org.apache.phoenix.end2end.ExplainPlanWithStatsEnabledIT.Estimate;
 import org.apache.phoenix.hbase.index.IndexRegionSplitPolicy;
 import org.apache.phoenix.jdbc.PhoenixConnection;
-import org.apache.phoenix.jdbc.PhoenixPreparedStatement;
 import org.apache.phoenix.jdbc.PhoenixResultSet;
 import org.apache.phoenix.jdbc.PhoenixStatement;
 import org.apache.phoenix.query.QueryConstants;
@@ -75,105 +73,13 @@ import org.apache.phoenix.util.SchemaUtil;
 import org.apache.phoenix.util.TestUtil;
 import org.junit.Test;
 
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 public class LocalIndexIT extends BaseLocalIndexIT {
     public LocalIndexIT(boolean isNamespaceMapped) {
         super(isNamespaceMapped);
     }
 
-    @Test
-    public void testSelectFromIndexWithAdditionalWhereClause() throws Exception {
-        if (isNamespaceMapped) {
-            return;
-        }
-        String tableName = schemaName + "." + generateUniqueName();
-        String indexName = "IDX_" + generateUniqueName();
-
-        Connection conn = getConnection();
-        conn.setAutoCommit(true);
-
-        conn.createStatement().execute("CREATE TABLE " + tableName + " (pk INTEGER PRIMARY KEY, v1 FLOAT, v2 FLOAT, v3 INTEGER)");
-        conn.createStatement().execute("UPSERT INTO " + tableName + " VALUES(1, 2, 3, 4)");
-        conn.createStatement().execute("UPSERT INTO " + tableName + " VALUES(2, 3, 4, 5)");
-        conn.createStatement().execute("UPSERT INTO " + tableName + " VALUES(3, 4, 5, 6)");
-        conn.createStatement().execute("UPSERT INTO " + tableName + " VALUES(4, 5, 6, 7)");
-
-        conn.createStatement().execute("CREATE LOCAL INDEX " + indexName + " ON " + tableName + "(v1)");
-        testExtraWhere(conn, tableName);
-
-        conn.createStatement().execute("DROP INDEX " + indexName + " ON " + tableName);
-        conn.createStatement().execute("CREATE LOCAL INDEX " + indexName + " ON " + tableName + "(v1) INCLUDE (v3)");
-        testExtraWhere(conn, tableName);
-
-        conn.createStatement().execute("DROP INDEX " + indexName + " ON " + tableName);
-        conn.createStatement().execute("CREATE LOCAL INDEX " + indexName + " ON " + tableName + "(v1) INCLUDE (v2)");
-        testExtraWhere(conn, tableName);
-
-        conn.createStatement().execute("DROP INDEX " + indexName + " ON " + tableName);
-        conn.createStatement().execute("CREATE LOCAL INDEX " + indexName + " ON " + tableName + "(v1) INCLUDE (v2,v3)");
-        testExtraWhere(conn, tableName);
-    }
-
-    private void testExtraWhere(Connection conn, String tableName) throws SQLException {
-        ResultSet rs = conn.createStatement().executeQuery("SELECT COUNT(*) FROM "+tableName+" WHERE v1 < 3 AND v2 < 4");
-        rs.next();
-        assertEquals(1, rs.getInt(1));
-        rs.close();
-
-        rs = conn.createStatement().executeQuery("SELECT COUNT(*) FROM "+tableName+" WHERE v1 < 3 AND v3 < 5");
-        rs.next();
-        assertEquals(1, rs.getInt(1));
-        rs.close();
-
-        rs = conn.createStatement().executeQuery("SELECT COUNT(*) FROM "+tableName+" WHERE v1 < 10 AND v2 < 0 AND v3 < 0");
-        rs.next();
-        assertEquals(0, rs.getInt(1));
-        rs.close();
-
-        rs = conn.createStatement().executeQuery("SELECT COUNT(*) FROM "+tableName+" WHERE v1 <= 2 AND v2 > 0 AND v3 < 5");
-        rs.next();
-        assertEquals(1, rs.getInt(1));
-        rs.close();
-
-        rs = conn.createStatement().executeQuery("SELECT pk FROM "+tableName+" WHERE v1 > 3 AND v2 > 0 AND v3 > 6");
-        rs.next();
-        assertEquals(4, rs.getInt(1));
-        rs.close();
-
-        rs = conn.createStatement().executeQuery("SELECT v1 FROM "+tableName+" WHERE v1 > 3 AND v2 > 0 AND v3 > 6");
-        rs.next();
-        assertEquals(5, rs.getInt(1));
-        rs.close();
-
-        rs = conn.createStatement().executeQuery("SELECT pk FROM "+tableName+" WHERE (v1,v2) IN ((1,5),(4,5))");
-        rs.next();
-        assertEquals(3, rs.getInt(1));
-        rs.close();
-
-        rs = conn.createStatement().executeQuery("SELECT v3 FROM "+tableName+" WHERE (v1,v2) IN ((1,5),(4,5))");
-        rs.next();
-        assertEquals(6, rs.getInt(1));
-        rs.close();
-
-        rs = conn.createStatement().executeQuery("SELECT * FROM "+tableName+" WHERE v1 > 0 AND v3 > 5 LIMIT 2");
-        assertTrue(rs.next());
-        assertTrue(rs.next());
-        assertFalse(rs.next());
-        rs.close();
-
-        rs = conn.createStatement().executeQuery("SELECT * FROM "+tableName+" WHERE v1 > 0 AND v3 > 5 LIMIT 1");
-        assertTrue(rs.next());
-        assertFalse(rs.next());
-        rs.close();
-
-        rs = conn.createStatement().executeQuery("SELECT * FROM "+tableName+" WHERE v3 > 5 ORDER BY v1 LIMIT 2");
-        assertTrue(rs.next());
-        assertTrue(rs.next());
-        assertFalse(rs.next());
-        rs.close();
-    }
-
     @Test
     public void testDeleteFromLocalIndex() throws Exception {
         String tableName = schemaName + "." + generateUniqueName();
@@ -280,67 +186,41 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         conn.createStatement().execute("CREATE LOCAL INDEX " + indexName + " ON " + tableName + "(pk1,pk2,v1,v2)");
 
         // 1. same prefix length, no other restrictions, but v3 is in the SELECT. Use the main table.
-        ExplainPlan explainPlan = conn.prepareStatement("SELECT * FROM " + tableName + " WHERE pk1 = 3 AND pk2 = 4")
-                .unwrap(PhoenixPreparedStatement.class).optimizeQuery()
-                .getExplainPlan();
-        ExplainPlanAttributes explainPlanAttributes =
-                explainPlan.getPlanStepsAsAttributes();
-        assertEquals("PARALLEL 1-WAY",
-                explainPlanAttributes.getIteratorTypeAndScanSize());
-        assertEquals("RANGE SCAN ",
-                explainPlanAttributes.getExplainScanType());
-        assertEquals(physicalTableName.toString(), explainPlanAttributes.getTableName());
-        assertEquals(" [3,4]", explainPlanAttributes.getKeyRanges());
+        ResultSet rs = conn.createStatement().executeQuery("EXPLAIN SELECT * FROM " + tableName + " WHERE pk1 = 3 AND pk2 = 4");
+        assertEquals(
+            "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
+                    + physicalTableName + " [3,4]",
+                    QueryUtil.getExplainPlan(rs));
+        rs.close();
 
         // 2. same prefix length, no other restrictions. Only index columns used. Use the index.
-        explainPlan = conn.prepareStatement("SELECT v2 FROM " + tableName + " WHERE pk1 = 3 AND pk2 = 4")
-                .unwrap(PhoenixPreparedStatement.class).optimizeQuery()
-                .getExplainPlan();
-        explainPlanAttributes =
-                explainPlan.getPlanStepsAsAttributes();
-        assertEquals("PARALLEL 1-WAY",
-                explainPlanAttributes.getIteratorTypeAndScanSize());
-        assertEquals("RANGE SCAN ",
-                explainPlanAttributes.getExplainScanType());
-        assertEquals(indexPhysicalTableName, explainPlanAttributes.getTableName());
-        assertEquals(" [1,3,4]", explainPlanAttributes.getKeyRanges());
-        assertEquals("SERVER FILTER BY FIRST KEY ONLY",
-                explainPlanAttributes.getServerWhereFilter());
-        assertEquals("CLIENT MERGE SORT",
-                explainPlanAttributes.getClientSortAlgo());
+        rs = conn.createStatement().executeQuery("EXPLAIN SELECT v2 FROM " + tableName + " WHERE pk1 = 3 AND pk2 = 4");
+        assertEquals(
+                "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
+                        + indexPhysicalTableName + " [1,3,4]\n"
+                                + "    SERVER FILTER BY FIRST KEY ONLY\n"
+                                + "CLIENT MERGE SORT",
+                        QueryUtil.getExplainPlan(rs));
+        rs.close();
 
         // 3. same prefix length, but there's a column not on the index
-        explainPlan = conn.prepareStatement("SELECT v2 FROM " + tableName + " WHERE pk1 = 3 AND pk2 = 4 AND v3 = 1")
-                .unwrap(PhoenixPreparedStatement.class).optimizeQuery()
-                .getExplainPlan();
-        explainPlanAttributes =
-                explainPlan.getPlanStepsAsAttributes();
-        assertEquals("PARALLEL 1-WAY",
-                explainPlanAttributes.getIteratorTypeAndScanSize());
-        assertEquals("RANGE SCAN ",
-                explainPlanAttributes.getExplainScanType());
-        assertEquals(physicalTableName.toString(), explainPlanAttributes.getTableName());
-        assertEquals(" [3,4]", explainPlanAttributes.getKeyRanges());
-        assertEquals("SERVER FILTER BY V3 = 1",
-                explainPlanAttributes.getServerWhereFilter());
+        rs = conn.createStatement().executeQuery("EXPLAIN SELECT v2 FROM " + tableName + " WHERE pk1 = 3 AND pk2 = 4 AND v3 = 1");
+        assertEquals(
+            "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
+                    + physicalTableName + " [3,4]\n"
+                    + "    SERVER FILTER BY V3 = 1",
+                    QueryUtil.getExplainPlan(rs));
+        rs.close();
 
         // 4. Longer prefix on the index, use it.
-        explainPlan = conn.prepareStatement("SELECT v2 FROM " + tableName + " WHERE pk1 = 3 AND pk2 = 4 AND v1 = 3 AND v3 = 1")
-                .unwrap(PhoenixPreparedStatement.class).optimizeQuery()
-                .getExplainPlan();
-        explainPlanAttributes =
-                explainPlan.getPlanStepsAsAttributes();
-        assertEquals("PARALLEL 1-WAY",
-                explainPlanAttributes.getIteratorTypeAndScanSize());
-        assertEquals("RANGE SCAN ",
-                explainPlanAttributes.getExplainScanType());
-        assertEquals(physicalTableName.toString(), explainPlanAttributes.getTableName());
-        assertEquals(" [1,3,4,3]", explainPlanAttributes.getKeyRanges());
-        assertEquals("[0.V3]", explainPlanAttributes.getServerMergeColumns().toString());
-        assertEquals("SERVER FILTER BY FIRST KEY ONLY AND \"V3\" = 1",
-                explainPlanAttributes.getServerWhereFilter());
-        assertEquals("CLIENT MERGE SORT",
-                explainPlanAttributes.getClientSortAlgo());
+        rs = conn.createStatement().executeQuery("EXPLAIN SELECT v2 FROM " + tableName + " WHERE pk1 = 3 AND pk2 = 4 AND v1 = 3 AND v3 = 1");
+        assertEquals(
+            "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
+                    + physicalTableName + " [1,3,4,3]\n"
+                    + "    SERVER FILTER BY FIRST KEY ONLY AND \"V3\" = 1\n"
+                    + "CLIENT MERGE SORT",
+                    QueryUtil.getExplainPlan(rs));
+        rs.close();
     }
 
     @Test
@@ -366,7 +246,6 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         assertEquals(
             "CLIENT PARALLEL 16-WAY RANGE SCAN OVER "
                     + indexPhysicalTableName + " [1,2,3]\n"
-                    + "    SERVER MERGE [0.V1]\n"
                     + "    SERVER FILTER BY FIRST KEY ONLY\n"
                     + "CLIENT MERGE SORT",
                     QueryUtil.getExplainPlan(rs));
@@ -412,7 +291,6 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         assertEquals(
             "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
                     + indexPhysicalTableName + " [1]\n"
-                            + "    SERVER MERGE [0.V1]\n"
                             + "    SERVER FILTER BY FIRST KEY ONLY\n"
                             + "CLIENT MERGE SORT",
                     QueryUtil.getExplainPlan(rs));
@@ -433,7 +311,6 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         assertEquals(
             "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
                     + indexPhysicalTableName + " [1,2]\n"
-                            + "    SERVER MERGE [0.V1]\n"
                             + "    SERVER FILTER BY FIRST KEY ONLY\n"
                             + "CLIENT MERGE SORT",
                     QueryUtil.getExplainPlan(rs));
@@ -462,7 +339,6 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         assertEquals(
             "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
                     + indexPhysicalTableName + " [1,2]\n"
-                            + "    SERVER MERGE [0.V1]\n"
                             + "    SERVER FILTER BY FIRST KEY ONLY\n"
                             + "CLIENT MERGE SORT",
                     QueryUtil.getExplainPlan(rs));
@@ -473,7 +349,6 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         assertEquals(
             "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
                     + indexPhysicalTableName + " [1,2]\n"
-                            + "    SERVER MERGE [0.V1]\n"
                             + "    SERVER FILTER BY FIRST KEY ONLY AND TO_INTEGER(\"V4\") = 4\n"
                             + "CLIENT MERGE SORT",
                     QueryUtil.getExplainPlan(rs));
@@ -484,9 +359,8 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         assertEquals(
             "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
                     + indexPhysicalTableName + " [1,2]\n"
-                    + "    SERVER MERGE [0.V1]\n"
-                    + "    SERVER FILTER BY FIRST KEY ONLY AND \"V1\" = 3.0\n"
-                    + "CLIENT MERGE SORT",
+                            + "    SERVER FILTER BY FIRST KEY ONLY AND \"V1\" = 3.0\n"
+                            + "CLIENT MERGE SORT",
                     QueryUtil.getExplainPlan(rs));
         rs.close();
 
@@ -595,15 +469,16 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         Connection conn2 = getConnection();
         conn1.createStatement().execute("CREATE LOCAL INDEX " + indexName + " ON " + tableName + "(v1)");
         conn2.createStatement().executeQuery("SELECT * FROM " + tableName).next();
-        HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
-        HTableDescriptor htd = admin
-                .getTableDescriptor(Bytes.toBytes(indexPhysicalTableName));
-        assertEquals(IndexRegionSplitPolicy.class.getName(), htd.getValue(HTableDescriptor.SPLIT_POLICY));
-        try (HTable userTable = new HTable(admin.getConfiguration(),
-                SchemaUtil.getPhysicalTableName(tableName.getBytes(), isNamespaceMapped))) {
-            try (HTable indexTable = new HTable(admin.getConfiguration(), Bytes.toBytes(indexPhysicalTableName))) {
-                assertArrayEquals("Both user table and index table should have same split keys.",
-                        userTable.getStartKeys(), indexTable.getStartKeys());
+        Admin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
+        TableDescriptor htd = admin
+                .getDescriptor(TableName.valueOf(indexPhysicalTableName));
+        assertEquals(IndexRegionSplitPolicy.class.getName(), htd.getValue(TableDescriptorBuilder.SPLIT_POLICY));
+        try(org.apache.hadoop.hbase.client.Connection c = ConnectionFactory.createConnection(admin.getConfiguration())) {
+            try (RegionLocator userTable= c.getRegionLocator(SchemaUtil.getPhysicalTableName(tableName.getBytes(), isNamespaceMapped))) {
+                try (RegionLocator indxTable = c.getRegionLocator(TableName.valueOf(indexPhysicalTableName))) {
+                    assertArrayEquals("Both user table and index table should have same split keys.",
+                        userTable.getStartKeys(), indxTable.getStartKeys());
+                }
             }
         }
     }
@@ -645,9 +520,12 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         ResultSet rs = conn1.createStatement().executeQuery("SELECT COUNT(*) FROM " + indexTableName);
         assertTrue(rs.next());
         assertEquals(4, rs.getInt(1));
-        HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
-        HTable indexTable = new HTable(admin.getConfiguration(), indexPhysicalTableName);
-        Pair<byte[][], byte[][]> startEndKeys = indexTable.getStartEndKeys();
+        Admin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
+        Table indexTable =
+                admin.getConnection().getTable(TableName.valueOf(indexPhysicalTableName));
+        Pair<byte[][], byte[][]> startEndKeys =
+                admin.getConnection().getRegionLocator(TableName.valueOf(indexPhysicalTableName))
+                        .getStartEndKeys();
         byte[][] startKeys = startEndKeys.getFirst();
         byte[][] endKeys = startEndKeys.getSecond();
         for (int i = 0; i < startKeys.length; i++) {
@@ -685,13 +563,12 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             String query = "SELECT * FROM " + tableName +" ORDER BY V1";
             ResultSet rs = conn1.createStatement().executeQuery("EXPLAIN "+ query);
 
-            HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
+            Admin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
             int numRegions = admin.getTableRegions(physicalTableName).size();
 
             assertEquals(
                 "CLIENT PARALLEL " + numRegions + "-WAY RANGE SCAN OVER "
                         + indexPhysicalTableName + " [1]\n"
-                                + "    SERVER MERGE [0.K3]\n"
                                 + "    SERVER FILTER BY FIRST KEY ONLY\n"
                                 + "CLIENT MERGE SORT",
                         QueryUtil.getExplainPlan(rs));
@@ -714,7 +591,6 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             assertEquals(
                 "CLIENT PARALLEL " + numRegions + "-WAY REVERSE RANGE SCAN OVER "
                         + indexPhysicalTableName + " [1]\n"
-                                + "    SERVER MERGE [0.K3]\n"
                                 + "    SERVER FILTER BY FIRST KEY ONLY\n"
                                 + "CLIENT MERGE SORT",
                         QueryUtil.getExplainPlan(rs));
@@ -754,7 +630,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             String query = "SELECT V1 FROM " + tableName +" ORDER BY V1 DESC NULLS LAST";
             ResultSet rs = conn1.createStatement().executeQuery("EXPLAIN "+ query);
 
-            HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
+            Admin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
             int numRegions = admin.getTableRegions(physicalTableName).size();
 
             assertEquals(
@@ -801,7 +677,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             ResultSet rs = conn1.createStatement().executeQuery("SELECT COUNT(*) FROM " + indexTableName);
             assertTrue(rs.next());
             
-            HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
+            Admin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
             int numRegions = admin.getTableRegions(physicalTableName).size();
             
             String query = "SELECT t_id, k1, k2, k3, V1 FROM " + tableName +" where v1='a'";
@@ -810,7 +686,6 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             assertEquals(
                 "CLIENT PARALLEL " + numRegions + "-WAY RANGE SCAN OVER "
                         + indexPhysicalTableName + " [1,'a']\n"
-                                + "    SERVER MERGE [0.K3]\n"
                                 + "    SERVER FILTER BY FIRST KEY ONLY\n"
                                 + "CLIENT MERGE SORT",
                         QueryUtil.getExplainPlan(rs));
@@ -834,7 +709,6 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             assertEquals(
                 "CLIENT PARALLEL " + numRegions + "-WAY RANGE SCAN OVER "
                         + indexPhysicalTableName +" [1,*] - [1,'z']\n"
-                        + "    SERVER MERGE [0.K3]\n"
                         + "    SERVER FILTER BY FIRST KEY ONLY\n"
                          + "CLIENT MERGE SORT",
                 QueryUtil.getExplainPlan(rs));
@@ -871,7 +745,6 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             assertEquals(
                 "CLIENT PARALLEL " + numRegions + "-WAY RANGE SCAN OVER "
                         + indexPhysicalTableName +" [1,*] - [1,'z']\n"
-                        + "    SERVER MERGE [0.K3]\n"
                         + "    SERVER FILTER BY FIRST KEY ONLY\n"
                         + "    SERVER AGGREGATE INTO DISTINCT ROWS BY [\"V1\", \"T_ID\", \"K3\"]\nCLIENT MERGE SORT",
                 QueryUtil.getExplainPlan(rs));
@@ -900,7 +773,6 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             assertEquals(
                 "CLIENT PARALLEL " + numRegions + "-WAY RANGE SCAN OVER "
                         + indexPhysicalTableName +" [1,*] - [1,'z']\n"
-                        + "    SERVER MERGE [0.K3]\n"
                         + "    SERVER FILTER BY FIRST KEY ONLY\n"
                         + "    SERVER AGGREGATE INTO ORDERED DISTINCT ROWS BY [\"V1\"]\nCLIENT MERGE SORT",
                 QueryUtil.getExplainPlan(rs));
@@ -963,9 +835,12 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             conn1.commit();
             conn1.createStatement().execute("CREATE LOCAL INDEX " + indexName + " ON " + tableName + "(v1)");
             conn1.createStatement().execute("DROP INDEX " + indexName + " ON " + tableName);
-            HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
-            HTable table = new HTable(admin.getConfiguration() ,TableName.valueOf(tableName));
-            Pair<byte[][], byte[][]> startEndKeys = table.getStartEndKeys();
+            Admin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
+            Table table =
+                    admin.getConnection().getTable(TableName.valueOf(tableName));
+            Pair<byte[][], byte[][]> startEndKeys =
+                    admin.getConnection().getRegionLocator(TableName.valueOf(tableName))
+                            .getStartEndKeys();
             byte[][] startKeys = startEndKeys.getFirst();
             byte[][] endKeys = startEndKeys.getSecond();
             // No entry should be present in local index table after drop index.
@@ -973,8 +848,8 @@ public class LocalIndexIT extends BaseLocalIndexIT {
                 Scan s = new Scan();
                 s.setStartRow(startKeys[i]);
                 s.setStopRow(endKeys[i]);
-                Collection<HColumnDescriptor> families = table.getTableDescriptor().getFamilies();
-                for(HColumnDescriptor cf: families) {
+                ColumnFamilyDescriptor[] families = table.getDescriptor().getColumnFamilies();
+                for(ColumnFamilyDescriptor cf: families) {
                     if(cf.getNameAsString().startsWith(QueryConstants.LOCAL_INDEX_COLUMN_FAMILY_PREFIX)){
                         s.addFamily(cf.getName());
                     }
@@ -1120,8 +995,8 @@ public class LocalIndexIT extends BaseLocalIndexIT {
     public void testLocalIndexAutomaticRepair() throws Exception {
         if (isNamespaceMapped) { return; }
         PhoenixConnection conn = DriverManager.getConnection(getUrl()).unwrap(PhoenixConnection.class);
-        try (HTableInterface metaTable = conn.getQueryServices().getTable(TableName.META_TABLE_NAME.getName());
-                HBaseAdmin admin = conn.getQueryServices().getAdmin();) {
+        try (Table metaTable = conn.getQueryServices().getTable(TableName.META_TABLE_NAME.getName());
+                Admin admin = conn.getQueryServices().getAdmin();) {
             Statement statement = conn.createStatement();
             final String tableName = "T_AUTO_MATIC_REPAIR";
             String indexName = "IDX_T_AUTO_MATIC_REPAIR";
@@ -1137,11 +1012,11 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             ResultSet rs = statement.executeQuery("SELECT COUNT(*) FROM " + indexName);
             assertTrue(rs.next());
             assertEquals(2000, rs.getLong(1));
-            List<HRegionInfo> tableRegions = admin.getTableRegions(TableName.valueOf(tableName));
-            admin.disableTable(tableName);
+            List<RegionInfo> tableRegions = admin.getRegions(TableName.valueOf(tableName));
+            admin.disableTable(TableName.valueOf(tableName));
             copyLocalIndexHFiles(config, tableRegions.get(0), tableRegions.get(1), false);
             copyLocalIndexHFiles(config, tableRegions.get(3), tableRegions.get(0), false);
-            admin.enableTable(tableName);
+            admin.enableTable(TableName.valueOf(tableName));
 
             int count=getCount(conn, tableName, "L#0");
             assertTrue(count > 4000);
@@ -1230,17 +1105,22 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         conn1.close();
     }
 
-    private void copyLocalIndexHFiles(Configuration conf, HRegionInfo fromRegion, HRegionInfo toRegion, boolean move)
-            throws IOException {
-        Path root = FSUtils.getRootDir(conf);
+    private void copyLocalIndexHFiles(Configuration conf, RegionInfo fromRegion,
+            RegionInfo toRegion, boolean move) throws IOException {
+        Path root = CommonFSUtils.getRootDir(conf);
 
-        Path seondRegion = new Path(HTableDescriptor.getTableDir(root, fromRegion.getTableName()) + Path.SEPARATOR
-                + fromRegion.getEncodedName() + Path.SEPARATOR + "L#0/");
-        Path hfilePath = FSUtils.getCurrentFileSystem(conf).listFiles(seondRegion, true).next().getPath();
-        Path firstRegionPath = new Path(HTableDescriptor.getTableDir(root, toRegion.getTableName()) + Path.SEPARATOR
-                + toRegion.getEncodedName() + Path.SEPARATOR + "L#0/");
-        FileSystem currentFileSystem = FSUtils.getCurrentFileSystem(conf);
-        assertTrue(FileUtil.copy(currentFileSystem, hfilePath, currentFileSystem, firstRegionPath, move, conf));
+        Path seondRegion =
+                new Path(CommonFSUtils.getTableDir(root, fromRegion.getTable()) + Path.SEPARATOR
+                        + fromRegion.getEncodedName() + Path.SEPARATOR + "L#0/");
+        Path hfilePath =
+                CommonFSUtils.getCurrentFileSystem(conf).listFiles(seondRegion, true).next()
+                        .getPath();
+        Path firstRegionPath =
+                new Path(CommonFSUtils.getTableDir(root, toRegion.getTable()) + Path.SEPARATOR
+                        + toRegion.getEncodedName() + Path.SEPARATOR + "L#0/");
+        FileSystem currentFileSystem = CommonFSUtils.getCurrentFileSystem(conf);
+        assertTrue(FileUtil.copy(currentFileSystem, hfilePath, currentFileSystem, firstRegionPath,
+            move, conf));
     }
 
     private int getCount(PhoenixConnection conn, String tableName, String columnFamily)
