@@ -94,9 +94,10 @@ import org.apache.phoenix.util.IndexUtil;
 import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.ScanUtil;
 
-import com.google.common.base.Preconditions;
-import com.google.common.collect.Lists;
-import com.sun.istack.NotNull;
+import org.apache.phoenix.thirdparty.com.google.common.base.Preconditions;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+
+import edu.umd.cs.findbugs.annotations.NonNull;
 import org.apache.phoenix.util.SchemaUtil;
 
 public class DeleteCompiler {
@@ -269,7 +270,7 @@ public class DeleteCompiler {
                     connection.getMutationState().send();
                     mutations.clear();
                     if (otherMutations != null) {
-                        for(MultiRowMutationState multiRowMutationState: otherMutations) {
+                        for (MultiRowMutationState multiRowMutationState : otherMutations) {
                             multiRowMutationState.clear();
                         }
                     }
@@ -356,7 +357,7 @@ public class DeleteCompiler {
         private final MutationPlan firstPlan;
         private final QueryPlan dataPlan;
 
-        public MultiRowDeleteMutationPlan(QueryPlan dataPlan, @NotNull List<MutationPlan> plans) {
+        public MultiRowDeleteMutationPlan(QueryPlan dataPlan, @NonNull List<MutationPlan> plans) {
             Preconditions.checkArgument(!plans.isEmpty());
             this.plans = plans;
             this.firstPlan = plans.get(0);
