@@ -28,9 +28,11 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import org.apache.phoenix.thirdparty.com.google.common.base.Optional;
 import org.apache.hadoop.hbase.client.Scan;
-import org.apache.hadoop.hbase.regionserver.ScanInfoUtil;
 import org.apache.hadoop.hbase.util.Pair;
+import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
+import org.apache.phoenix.compat.hbase.coprocessor.CompatBaseScannerRegionObserver;
 import org.apache.phoenix.compile.GroupByCompiler.GroupBy;
 import org.apache.phoenix.compile.JoinCompiler.JoinSpec;
 import org.apache.phoenix.compile.JoinCompiler.JoinTable;
@@ -87,9 +89,8 @@ import org.apache.phoenix.util.ParseNodeUtil.RewriteResult;
 import org.apache.phoenix.util.QueryUtil;
 import org.apache.phoenix.util.ScanUtil;
 
-import com.google.common.collect.Lists;
-import com.google.common.collect.Sets;
-import com.google.common.base.Optional;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
 
 
 /**
@@ -105,6 +106,7 @@ public class QueryCompiler {
     private final Scan scan;
     private final Scan originalScan;
     private final ColumnResolver resolver;
+    private final BindManager bindManager;
     private final SelectStatement select;
     private final List<? extends PDatum> targetColumns;
     private final ParallelIteratorFactory parallelIteratorFactory;
@@ -120,10 +122,19 @@ public class QueryCompiler {
         this(statement, select, resolver, Collections.<PDatum>emptyList(), null, new SequenceManager(statement), projectTuples, optimizeSubquery, dataPlans);
     }
 
+    public QueryCompiler(PhoenixStatement statement, SelectStatement select, ColumnResolver resolver, BindManager bindManager, boolean projectTuples, boolean optimizeSubquery, Map<TableRef, QueryPlan> dataPlans) throws SQLException {
+        this(statement, select, resolver, bindManager, Collections.<PDatum>emptyList(), null, new SequenceManager(statement), projectTuples, optimizeSubquery, dataPlans);
+    }
+
     public QueryCompiler(PhoenixStatement statement, SelectStatement select, ColumnResolver resolver, List<? extends PDatum> targetColumns, ParallelIteratorFactory parallelIteratorFactory, SequenceManager sequenceManager, boolean projectTuples, boolean optimizeSubquery, Map<TableRef, QueryPlan> dataPlans) throws SQLException {
+        this(statement, select, resolver, new BindManager(statement.getParameters()), targetColumns, parallelIteratorFactory, sequenceManager, projectTuples, optimizeSubquery, dataPlans);
+    }
+
+    public QueryCompiler(PhoenixStatement statement, SelectStatement select, ColumnResolver resolver, BindManager bindManager, List<? extends PDatum> targetColumns, ParallelIteratorFactory parallelIteratorFactory, SequenceManager sequenceManager, boolean projectTuples, boolean optimizeSubquery, Map<TableRef, QueryPlan> dataPlans) throws SQLException {
         this.statement = statement;
         this.select = select;
         this.resolver = resolver;
+        this.bindManager = bindManager;
         this.scan = new Scan();
         this.targetColumns = targetColumns;
         this.parallelIteratorFactory = parallelIteratorFactory;
@@ -170,6 +181,9 @@ public class QueryCompiler {
     }
 
     private void verifySCN() throws SQLException {
+        if (!HbaseCompatCapabilities.isMaxLookbackTimeSupported()) {
+            return;
+        }
         PhoenixConnection conn = statement.getConnection();
         if (conn.isRunningUpgrade()) {
             // PHOENIX-6179 : if upgrade is going on, we don't need to
@@ -182,11 +196,11 @@ public class QueryCompiler {
         }
         ColumnResolver resolver =
             FromCompiler.getResolverForQuery(select, conn);
-        int maxLookBackAge = conn.getQueryServices().
-            getConfiguration().getInt(ScanInfoUtil.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY,
-            ScanInfoUtil.DEFAULT_PHOENIX_MAX_LOOKBACK_AGE);
+        long maxLookBackAgeInMillis =
+            CompatBaseScannerRegionObserver.getMaxLookbackInMillis(conn.getQueryServices().
+            getConfiguration());
         long now = EnvironmentEdgeManager.currentTimeMillis();
-        if (maxLookBackAge > 0 && now - maxLookBackAge * 1000L > scn){
+        if (maxLookBackAgeInMillis > 0 && now - maxLookBackAgeInMillis > scn){
             throw new SQLExceptionInfo.Builder(
                 SQLExceptionCode.CANNOT_QUERY_TABLE_WITH_SCN_OLDER_THAN_MAX_LOOKBACK_AGE)
                 .build().buildException();
@@ -213,7 +227,7 @@ public class QueryCompiler {
         TableRef tableRef = UnionCompiler.contructSchemaTable(statement, plans,
             select.hasWildcard() ? null : select.getSelect());
         ColumnResolver resolver = FromCompiler.getResolver(tableRef);
-        StatementContext context = new StatementContext(statement, resolver, scan, sequenceManager);
+        StatementContext context = new StatementContext(statement, resolver, bindManager, scan, sequenceManager);
         QueryPlan plan = compileSingleFlatQuery(
                 context,
                 select,
@@ -231,7 +245,7 @@ public class QueryCompiler {
 
     public QueryPlan compileSelect(SelectStatement select) throws SQLException{
         List<Object> binds = statement.getParameters();
-        StatementContext context = new StatementContext(statement, resolver, scan, sequenceManager);
+        StatementContext context = new StatementContext(statement, resolver, bindManager, scan, sequenceManager);
         if (select.isJoin()) {
             JoinTable joinTable = JoinCompiler.compile(statement, select, context.getResolver());
             return compileJoinQuery(context, binds, joinTable, false, false, null);
@@ -295,7 +309,7 @@ public class QueryCompiler {
         Cost bestCost = null;
         for (JoinCompiler.Strategy strategy : strategies) {
             StatementContext newContext = new StatementContext(
-                    context.getStatement(), context.getResolver(), new Scan(), context.getSequenceManager());
+                    context.getStatement(), context.getResolver(), context.getBindManager(), new Scan(), context.getSequenceManager());
             QueryPlan plan = compileJoinQuery(
                     strategy, newContext, binds, joinTable, asSubquery, projectPKColumns, orderBy);
             Cost cost = plan.getCost();
@@ -354,7 +368,7 @@ public class QueryCompiler {
                 for (int i = 0; i < count; i++) {
                     JoinSpec joinSpec = joinSpecs.get(i);
                     Scan subScan = ScanUtil.newScan(originalScan);
-                    subContexts[i] = new StatementContext(statement, context.getResolver(), subScan, new SequenceManager(statement));
+                    subContexts[i] = new StatementContext(statement, context.getResolver(), context.getBindManager(), subScan, new SequenceManager(statement));
                     subPlans[i] = compileJoinQuery(
                             subContexts[i],
                             binds,
@@ -421,7 +435,7 @@ public class QueryCompiler {
                 Table rhsTable = rhsJoinTable.getLeftTable();
                 JoinTable lhsJoin = joinTable.createSubJoinTable(statement.getConnection());
                 Scan subScan = ScanUtil.newScan(originalScan);
-                StatementContext lhsCtx = new StatementContext(statement, context.getResolver(), subScan, new SequenceManager(statement));
+                StatementContext lhsCtx = new StatementContext(statement, context.getResolver(), context.getBindManager(), subScan, new SequenceManager(statement));
                 QueryPlan lhsPlan = compileJoinQuery(lhsCtx, binds, lhsJoin, true, true, null);
                 PTable rhsProjTable;
                 TableRef rhsTableRef;
@@ -519,13 +533,13 @@ public class QueryCompiler {
                 }
 
                 Scan lhsScan = ScanUtil.newScan(originalScan);
-                StatementContext lhsCtx = new StatementContext(statement, context.getResolver(), lhsScan, new SequenceManager(statement));
+                StatementContext lhsCtx = new StatementContext(statement, context.getResolver(), context.getBindManager(), lhsScan, new SequenceManager(statement));
                 boolean preserveRowkey = !projectPKColumns && type != JoinType.Full;
                 QueryPlan lhsPlan = compileJoinQuery(lhsCtx, binds, lhsJoin, true, !preserveRowkey, lhsOrderBy);
                 PTable lhsProjTable = lhsCtx.getResolver().getTables().get(0).getTable();
 
                 Scan rhsScan = ScanUtil.newScan(originalScan);
-                StatementContext rhsCtx = new StatementContext(statement, context.getResolver(), rhsScan, new SequenceManager(statement));
+                StatementContext rhsCtx = new StatementContext(statement, context.getResolver(), context.getBindManager(), rhsScan, new SequenceManager(statement));
                 QueryPlan rhsPlan = compileJoinQuery(rhsCtx, binds, rhsJoin, true, true, rhsOrderBy);
                 PTable rhsProjTable = rhsCtx.getResolver().getTables().get(0).getTable();
 
@@ -539,7 +553,7 @@ public class QueryCompiler {
 
                 ColumnResolver resolver = FromCompiler.getResolverForProjectedTable(projectedTable, context.getConnection(), joinTable.getOriginalJoinSelectStatement().getUdfParseNodes());
                 TableRef tableRef = resolver.getTables().get(0);
-                StatementContext subCtx = new StatementContext(statement, resolver, ScanUtil.newScan(originalScan), new SequenceManager(statement));
+                StatementContext subCtx = new StatementContext(statement, resolver, context.getBindManager(), ScanUtil.newScan(originalScan), new SequenceManager(statement));
                 subCtx.setCurrentTable(tableRef);
                 QueryPlan innerPlan = new SortMergeJoinPlan(
                         subCtx,
@@ -602,7 +616,7 @@ public class QueryCompiler {
             return false;
 
         Scan scanCopy = ScanUtil.newScan(context.getScan());
-        StatementContext contextCopy = new StatementContext(statement, context.getResolver(), scanCopy, new SequenceManager(statement));
+        StatementContext contextCopy = new StatementContext(statement, context.getResolver(), context.getBindManager(), scanCopy, new SequenceManager(statement));
         contextCopy.setCurrentTable(table);
         List<Expression> lhsCombination = Lists.<Expression> newArrayList();
         boolean complete = WhereOptimizer.getKeyExpressionCombination(lhsCombination, contextCopy, select, joinExpressions);
@@ -643,13 +657,14 @@ public class QueryCompiler {
                 this.statement,
                 rewriteResult.getRewrittenSelectStatement(),
                 rewriteResult.getColumnResolver(),
+                bindManager,
                 false,
                 optimizeSubquery,
                 null).compile();
         if (optimizeSubquery) {
             queryPlan = statement.getConnection().getQueryServices().getOptimizer().optimize(
-                         statement,
-                         queryPlan);
+                    statement,
+                    queryPlan);
         }
         this.statement.setMaxRows(maxRows); // restore maxRows.
         return queryPlan;
@@ -740,7 +755,7 @@ public class QueryCompiler {
                 .getConfiguration().getBoolean(WILDCARD_QUERY_DYNAMIC_COLS_ATTRIB,
                         DEFAULT_WILDCARD_QUERY_DYNAMIC_COLS_ATTRIB);
         RowProjector projector = ProjectionCompiler.compile(context, select, groupBy,
-                asSubquery ? Collections.<PDatum>emptyList() : targetColumns, where,
+                asSubquery ? Collections.emptyList() : targetColumns, where,
                 wildcardIncludesDynamicCols);
         OrderBy orderBy = OrderByCompiler.compile(
                 context,
