@@ -17,8 +17,9 @@
  */
 package org.apache.phoenix.coprocessor;
 
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 import org.apache.hadoop.hbase.Cell;
+import org.apache.hadoop.hbase.ExtendedCellBuilder;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.regionserver.Region;
@@ -27,7 +28,6 @@ import org.apache.hadoop.hbase.util.Pair;
 import org.apache.phoenix.coprocessor.MetaDataProtocol.MetaDataMutationResult;
 import org.apache.phoenix.hbase.index.util.ImmutableBytesPtr;
 import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
-import org.apache.phoenix.query.QueryConstants;
 import org.apache.phoenix.schema.ColumnFamilyNotFoundException;
 import org.apache.phoenix.schema.ColumnNotFoundException;
 import org.apache.phoenix.schema.PColumn;
@@ -294,7 +294,8 @@ public class AddColumnMutator implements ColumnMutator {
                                                          List<ImmutableBytesPtr> invalidateList,
                                                          List<Region.RowLock> locks,
                                                          long clientTimeStamp,
-                                                         final long clientVersion,
+                                                         long clientVersion,
+                                                         ExtendedCellBuilder extendedCellBuilder,
                                                          final boolean isAddingColumns) {
         byte[] tenantId = rowKeyMetaData[TENANT_ID_INDEX];
         byte[] schemaName = rowKeyMetaData[SCHEMA_NAME_INDEX];
@@ -334,11 +335,6 @@ public class AddColumnMutator implements ColumnMutator {
                                 EnvironmentEdgeManager.currentTimeMillis(), null);
                     }
                     if (familyName!=null && familyName.length > 0) {
-                        MetaDataMutationResult result =
-                                compareWithPkColumns(colName, table, familyName);
-                        if (result != null) {
-                            return result;
-                        }
                         PColumnFamily family =
                                 table.getColumnFamily(familyName);
                         family.getPColumnForColumnNameBytes(colName);
@@ -410,7 +406,7 @@ public class AddColumnMutator implements ColumnMutator {
             //We're changing the application-facing schema by adding a column, so update the DDL
             // timestamp
             long serverTimestamp = EnvironmentEdgeManager.currentTimeMillis();
-            if (MetaDataUtil.isTableTypeDirectlyQueried(table.getType())) {
+            if (MetaDataUtil.isTableDirectlyQueried(table.getType())) {
                 additionalTableMetadataMutations.add(MetaDataUtil.getLastDDLTimestampUpdate(tableHeaderRowKey,
                     clientTimeStamp, serverTimestamp));
             }
@@ -435,25 +431,8 @@ public class AddColumnMutator implements ColumnMutator {
             }
             // Pass in null as the parent PTable, since we always want to tag the cells
             // in this case, irrespective of the property values of the parent
-            ViewUtil.addTagsToPutsForViewAlteredProperties(tableMetaData, null);
-        }
-        return null;
-    }
-
-    private MetaDataMutationResult compareWithPkColumns(byte[] colName,
-            PTable table, byte[] familyName) {
-        // check if column is matching with any of pk columns if given
-        // column belongs to default CF
-        if (Bytes.compareTo(familyName, QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES) == 0
-                && colName != null && colName.length > 0) {
-            for (PColumn pColumn : table.getPKColumns()) {
-                if (Bytes.compareTo(
-                        pColumn.getName().getBytes(), colName) == 0) {
-                    return new MetaDataProtocol.MetaDataMutationResult(
-                            MetaDataProtocol.MutationCode.COLUMN_ALREADY_EXISTS,
-                            EnvironmentEdgeManager.currentTimeMillis(), table);
-                }
-            }
+            ViewUtil.addTagsToPutsForViewAlteredProperties(tableMetaData, null,
+                    extendedCellBuilder);
         }
         return null;
     }
