@@ -18,37 +18,24 @@
 package org.apache.phoenix.coprocessor;
 
 import java.io.IOException;
-import java.util.Collections;
 import java.util.List;
-import java.util.NavigableSet;
 
-import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
-import org.apache.hadoop.hbase.CoprocessorEnvironment;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
-import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.KeepDeletedCells;
 import org.apache.hadoop.hbase.NotServingRegionException;
 import org.apache.hadoop.hbase.client.Scan;
-import org.apache.hadoop.hbase.coprocessor.BaseRegionObserver;
 import org.apache.hadoop.hbase.coprocessor.ObserverContext;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.io.TimeRange;
-import org.apache.hadoop.hbase.regionserver.InternalScanner;
-import org.apache.hadoop.hbase.regionserver.KeyValueScanner;
 import org.apache.hadoop.hbase.regionserver.Region;
 import org.apache.hadoop.hbase.regionserver.RegionScanner;
-import org.apache.hadoop.hbase.regionserver.ScanInfo;
-import org.apache.hadoop.hbase.regionserver.ScanInfoUtil;
-import org.apache.hadoop.hbase.regionserver.ScanType;
 import org.apache.hadoop.hbase.regionserver.ScannerContext;
 import org.apache.hadoop.hbase.regionserver.ScannerContextUtil;
-import org.apache.hadoop.hbase.regionserver.Store;
-import org.apache.hadoop.hbase.regionserver.StoreScanner;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.htrace.Span;
 import org.apache.htrace.Trace;
+import org.apache.phoenix.compat.hbase.coprocessor.CompatBaseScannerRegionObserver;
 import org.apache.phoenix.execute.TupleProjector;
 import org.apache.phoenix.filter.PagedFilter;
 import org.apache.phoenix.hbase.index.covered.update.ColumnReference;
@@ -59,14 +46,10 @@ import org.apache.phoenix.schema.StaleRegionBoundaryCacheException;
 import org.apache.phoenix.schema.types.PUnsignedTinyint;
 import org.apache.phoenix.util.ScanUtil;
 import org.apache.phoenix.util.ServerUtil;
-import org.apache.phoenix.util.TransactionUtil;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
 import static org.apache.phoenix.util.ScanUtil.getPageSizeMsForFilter;
 
-abstract public class BaseScannerRegionObserver extends BaseRegionObserver {
-    private static final Logger LOG = LoggerFactory.getLogger(BaseScannerRegionObserver.class);
+abstract public class BaseScannerRegionObserver extends CompatBaseScannerRegionObserver {
 
     public static final String AGGREGATORS = "_Aggs";
     public static final String UNORDERED_GROUP_BY_EXPRESSIONS = "_UnorderedGroupByExpressions";
@@ -97,9 +80,6 @@ abstract public class BaseScannerRegionObserver extends BaseRegionObserver {
         "_IndexRebuildDisableLoggingVerifyType";
     public static final String INDEX_REBUILD_DISABLE_LOGGING_BEYOND_MAXLOOKBACK_AGE =
         "_IndexRebuildDisableLoggingBeyondMaxLookbackAge";
-    public static final String LOCAL_INDEX_FILTER = "_LocalIndexFilter";
-    public static final String LOCAL_INDEX_LIMIT = "_LocalIndexLimit";
-    public static final String LOCAL_INDEX_FILTER_STR = "_LocalIndexFilterStr";
 
     /* 
     * Attribute to denote that the index maintainer has been serialized using its proto-buf presentation.
@@ -149,6 +129,7 @@ abstract public class BaseScannerRegionObserver extends BaseRegionObserver {
     // In case of Index Write failure, we need to determine that Index mutation
     // is part of normal client write or Index Rebuilder. # PHOENIX-5080
     public final static byte[] REPLAY_INDEX_REBUILD_WRITES = PUnsignedTinyint.INSTANCE.toBytes(3);
+    
     public enum ReplayWrite {
         TABLE_AND_INDEX,
         INDEX_ONLY,
@@ -180,11 +161,6 @@ abstract public class BaseScannerRegionObserver extends BaseRegionObserver {
     /** Exposed for testing */
     public static final String SCANNER_OPENED_TRACE_INFO = "Scanner opened on server";
 
-    @Override
-    public void start(CoprocessorEnvironment e) throws IOException {
-        super.start(e);
-    }
-
     /**
      * Used by logger to identify coprocessor
      */
@@ -193,6 +169,7 @@ abstract public class BaseScannerRegionObserver extends BaseRegionObserver {
         return this.getClass().getName();
     }
 
+
     private static void throwIfScanOutOfRegion(Scan scan, Region region) throws DoNotRetryIOException {
         boolean isLocalIndex = ScanUtil.isLocalIndex(scan);
         byte[] lowerInclusiveScanKey = scan.getStartRow();
@@ -238,8 +215,8 @@ abstract public class BaseScannerRegionObserver extends BaseRegionObserver {
     }
 
     @Override
-    public RegionScanner preScannerOpen(final ObserverContext<RegionCoprocessorEnvironment> c,
-        final Scan scan, final RegionScanner s) throws IOException {
+    public void preScannerOpen(org.apache.hadoop.hbase.coprocessor.ObserverContext<RegionCoprocessorEnvironment> c,
+            Scan scan) throws IOException {
         byte[] txnScn = scan.getAttribute(TX_SCN);
         if (txnScn!=null) {
             TimeRange timeRange = scan.getTimeRange();
@@ -263,7 +240,6 @@ abstract public class BaseScannerRegionObserver extends BaseRegionObserver {
                 }
             }
         }
-        return s;
     }
 
     private class RegionScannerHolder extends DelegateRegionScanner {
@@ -410,106 +386,17 @@ abstract public class BaseScannerRegionObserver extends BaseRegionObserver {
     }
 
 
-    @Override
-    public KeyValueScanner preStoreScannerOpen(final ObserverContext<RegionCoprocessorEnvironment> c,
-                                               final Store store, final Scan scan,
-                                               final NavigableSet<byte[]> targetCols,
-                                               final KeyValueScanner s) throws IOException {
-        if (storeFileScanDoesntNeedAlteration(store, scan)) {
-            return s;
-        }
+   /* We want to override the store scanner so that we can read "past" a delete
+    marker on an SCN / lookback query to see the underlying edit. This was possible
+    in HBase 1.x, but not possible after the interface changes in HBase 2.0. HBASE-24321 in
+     HBase 2.3 gave us this ability back, but we need to use it through a compatibility shim
+     so we can compile against 2.1 and 2.2. When 2.3 is the minimum supported HBase
+     version, the shim can be retired and the logic moved into the real coproc.
 
-        if (s != null) {
-            s.close();
-        }
-        ScanInfo scanInfo = ScanInfoUtil.cloneScanInfoWithKeepDeletedCells(store.getScanInfo());
-        return ScanInfoUtil.createStoreScanner(store, scanInfo, scan, targetCols,
-            c.getEnvironment().getRegion().getReadpoint(scan.getIsolationLevel()));
-    }
+    We also need to override the flush compaction coproc hooks in order to implement max lookback
+     age to keep versions from being purged.
 
-    private boolean storeFileScanDoesntNeedAlteration(Store store, Scan scan) {
-        boolean isRaw = scan.isRaw();
-        //true if keep deleted cells is either TRUE or TTL
-        boolean keepDeletedCells = ScanInfoUtil.isKeepDeletedCells(store.getScanInfo());
-        boolean timeRangeIsLatest = scan.getTimeRange().getMax() == HConstants.LATEST_TIMESTAMP;
-        boolean timestampIsTransactional =
-            TransactionUtil.isTransactionalTimestamp(scan.getTimeRange().getMax());
-        return isRaw
-            || keepDeletedCells
-            || timeRangeIsLatest
-            || timestampIsTransactional;
-    }
+    Because the required APIs aren't present in HBase 2.1 and 2.2, we override in the 2.3
+     version of CompatBaseScannerRegionObserver and no-op in the other versions. */
 
-    @Override
-    public InternalScanner preFlushScannerOpen(final ObserverContext<RegionCoprocessorEnvironment> c,
-                                               final Store store,
-                                               final KeyValueScanner memstoreScanner,
-                                               final InternalScanner s)
-        throws IOException {
-
-        if (!ScanInfoUtil.isMaxLookbackTimeEnabled(c.getEnvironment().getConfiguration())){
-            return s;
-        }
-
-        //close last scanner object before creating a new one
-        if(s != null) {
-            s.close();
-        }
-
-        // Called during flushing the memstore to disk.
-        // Need to retain all the delete markers & all the versions
-        Scan scan = new Scan();
-        scan.setMaxVersions(Integer.MAX_VALUE);
-        ScanInfo oldScanInfo = store.getScanInfo();
-
-        Configuration conf = c.getEnvironment().getConfiguration();
-        //minor compactions and flushes both use "compact retain deletes"
-        ScanType scanType = ScanType.COMPACT_RETAIN_DELETES;
-        ScanInfo scanInfo =
-            ScanInfoUtil.getScanInfoForFlushesAndCompactions(conf, oldScanInfo, store, scanType);
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("Creating the store scanner with :" + scanInfo + ", " +
-                "scan object:" + scan + " for table " + store.getTableName().getNameAsString() +
-                " and region " + store.getRegionInfo().getRegionNameAsString() +
-                " and cf " + store.getColumnFamilyName());
-        }
-        return new StoreScanner(store, scanInfo, scan, Collections.singletonList(memstoreScanner),
-            scanType, store.getSmallestReadPoint(),
-            HConstants.LATEST_TIMESTAMP);
-    }
-
-    @Override
-    public InternalScanner preCompactScannerOpen(
-        final ObserverContext<RegionCoprocessorEnvironment> c, final Store store,
-        List<? extends KeyValueScanner> scanners, final ScanType scanType, final long earliestPutTs,
-        final InternalScanner s) throws IOException {
-
-        if (!ScanInfoUtil.isMaxLookbackTimeEnabled(c.getEnvironment().getConfiguration())){
-            return s;
-        }
-        //close last scanner object before creating a new one
-        if(s != null) {
-            s.close();
-        }
-        Scan scan = new Scan();
-        scan.setMaxVersions(Integer.MAX_VALUE);
-        ScanInfo oldScanInfo = store.getScanInfo();
-
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("Compaction triggering for table:" +
-                store.getRegionInfo().getTable().toString()
-                + " with scanType " + scanType  + " for table " +
-                store.getTableName().getNameAsString() + " and region " +
-                store.getRegionInfo().getRegionNameAsString() +
-                " and cf " + store.getColumnFamilyName());
-        }
-
-        Configuration conf = c.getEnvironment().getConfiguration();
-        ScanInfo scanInfo =
-            ScanInfoUtil.getScanInfoForFlushesAndCompactions(conf, oldScanInfo,
-                store, scanType);
-        return new StoreScanner(store, scanInfo, scan, scanners, scanType,
-            store.getSmallestReadPoint(),
-            earliestPutTs);
-    }
 }
