@@ -17,19 +17,17 @@
  */
 package org.apache.phoenix.coprocessor;
 
-import com.google.common.annotations.VisibleForTesting;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.HRegionInfo;
+
 import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.client.Delete;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Put;
+import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
@@ -39,15 +37,16 @@ import org.apache.hadoop.hbase.filter.FirstKeyOnlyFilter;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.regionserver.Region;
 import org.apache.hadoop.hbase.regionserver.RegionScanner;
-import org.apache.hadoop.hbase.regionserver.ScanInfoUtil;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.Pair;
-import org.apache.phoenix.compile.ScanRanges;
-import org.apache.phoenix.filter.AllVersionsIndexRebuildFilter;
+import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
+import org.apache.phoenix.compat.hbase.coprocessor.CompatBaseScannerRegionObserver;
 import org.apache.phoenix.filter.PagedFilter;
-import org.apache.phoenix.filter.SkipScanFilter;
 import org.apache.phoenix.hbase.index.ValueGetter;
 import org.apache.phoenix.hbase.index.covered.update.ColumnReference;
+import org.apache.phoenix.compile.ScanRanges;
+import org.apache.phoenix.filter.AllVersionsIndexRebuildFilter;
+import org.apache.phoenix.filter.SkipScanFilter;
 import org.apache.phoenix.hbase.index.parallel.EarlyExitFailure;
 import org.apache.phoenix.hbase.index.parallel.TaskBatch;
 import org.apache.phoenix.hbase.index.parallel.TaskRunner;
@@ -57,6 +56,7 @@ import org.apache.phoenix.hbase.index.parallel.WaitForCompletionTaskRunner;
 import org.apache.phoenix.hbase.index.table.HTableFactory;
 import org.apache.phoenix.hbase.index.util.GenericKeyValueBuilder;
 import org.apache.phoenix.hbase.index.util.ImmutableBytesPtr;
+import org.apache.phoenix.hbase.index.write.IndexWriterUtils;
 import org.apache.phoenix.hbase.index.util.IndexManagementUtil;
 import org.apache.phoenix.index.IndexMaintainer;
 import org.apache.phoenix.index.PhoenixIndexCodec;
@@ -66,6 +66,9 @@ import org.apache.phoenix.mapreduce.index.IndexVerificationResultRepository;
 import org.apache.phoenix.query.KeyRange;
 import org.apache.phoenix.query.QueryServicesOptions;
 import org.apache.phoenix.schema.types.PVarbinary;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
 import org.apache.phoenix.util.IndexUtil;
 import org.apache.phoenix.util.ServerUtil;
@@ -119,6 +122,7 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
     public static final String PHOENIX_INDEX_MR_LOG_BEYOND_MAX_LOOKBACK_ERRORS =
             "phoenix.index.mr.log.beyond.max.lookback.errors";
     public static final boolean DEFAULT_PHOENIX_INDEX_MR_LOG_BEYOND_MAX_LOOKBACK_ERRORS = false;
+
     protected final UngroupedAggregateRegionObserver ungroupedAggregateRegionObserver;
 
     protected IndexTool.IndexDisableLoggingType disableLoggingVerifyType = IndexTool.IndexDisableLoggingType.NONE;
@@ -157,6 +161,7 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
     protected Map<byte[], NavigableSet<byte[]>> familyMap;
     protected IndexTool.IndexVerifyType verifyType = IndexTool.IndexVerifyType.NONE;
     protected boolean verify = false;
+    protected boolean isRawFilterSupported;
 
     public GlobalIndexRegionScanner(final RegionScanner innerScanner,
                                     final Region region,
@@ -205,8 +210,8 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
             }
         }
         // Create the following objects only for rebuilds by IndexTool
-        hTableFactory = ServerUtil.getDelegateHTableFactory(env, ServerUtil.ConnectionType.INDEX_WRITER_CONNECTION);
-        maxLookBackInMills = ScanInfoUtil.getMaxLookbackInMillis(config);
+        hTableFactory = IndexWriterUtils.getDefaultDelegateHTableFactory(env);
+        maxLookBackInMills = CompatBaseScannerRegionObserver.getMaxLookbackInMillis(config);
         rowCountPerTask = config.getInt(INDEX_VERIFY_ROW_COUNTS_PER_TASK_CONF_KEY,
                 DEFAULT_INDEX_VERIFY_ROW_COUNTS_PER_TASK);
 
@@ -244,6 +249,7 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
                     new IndexVerificationResultRepository(indexMaintainer.getIndexTableName(), hTableFactory);
             nextStartKey = null;
             minTimestamp = scan.getTimeRange().getMin();
+            isRawFilterSupported = HbaseCompatCapabilities.isRawFilterSupported();
         }
     }
 
@@ -310,7 +316,7 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
 
     protected static boolean isTimestampBeyondMaxLookBack(long maxLookBackInMills,
             long currentTime, long tsToCheck) {
-        if (!ScanInfoUtil.isMaxLookbackTimeEnabled(maxLookBackInMills)) {
+        if (!CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(maxLookBackInMills)) {
             // By definition, if the max lookback feature is not enabled, then delete markers and rows
             // version can be removed by compaction any time, and thus there is no window in which these mutations are
             // preserved, i.e.,  the max lookback window size is zero. This means all the mutations are effectively
@@ -366,7 +372,7 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
     }
 
     @Override
-    public HRegionInfo getRegionInfo() {
+    public RegionInfo getRegionInfo() {
         return region.getRegionInfo();
     }
 
@@ -410,7 +416,7 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
             }
         }
         else {
-            this.pool.stop("IndexRegionObserverRegionScanner is closing");
+            this.pool.stop("GlobalIndexRegionScanner is closing");
             closeTables();
         }
     }
@@ -448,7 +454,7 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
     public void logToIndexToolOutputTable(byte[] dataRowKey, byte[] indexRowKey, long dataRowTs, long indexRowTs,
                                           String errorMsg, byte[] expectedVaue, byte[] actualValue, boolean isBeforeRebuild,
                                           IndexVerificationOutputRepository.IndexVerificationErrorType errorType) throws IOException {
-        ungroupedAggregateRegionObserver.checkForRegionClosing();
+        ungroupedAggregateRegionObserver.checkForRegionClosingOrSplitting();
         byte[] dataTableName = getDataTableName();
         verificationOutputRepository.logToIndexToolOutputTable(dataRowKey, indexRowKey, dataRowTs, indexRowTs,
                 errorMsg, expectedVaue, actualValue, scan.getTimeRange().getMax(),
@@ -1100,14 +1106,17 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
         for (byte[] indexKey : indexMutationMap.keySet()) {
             keys.add(PVarbinary.INSTANCE.getKeyRange(indexKey));
         }
+
         ScanRanges scanRanges = ScanRanges.createPointLookup(keys);
         Scan indexScan = new Scan();
         indexScan.setTimeRange(scan.getTimeRange().getMin(), scan.getTimeRange().getMax());
         scanRanges.initializeScan(indexScan);
-        SkipScanFilter skipScanFilter = scanRanges.getSkipScanFilter();
-        indexScan.setFilter(new SkipScanFilter(skipScanFilter, true));
+        if (isRawFilterSupported) {
+            SkipScanFilter skipScanFilter = scanRanges.getSkipScanFilter();
+            indexScan.setFilter(new SkipScanFilter(skipScanFilter, true));
+        }
         indexScan.setRaw(true);
-        indexScan.setMaxVersions();
+        indexScan.readAllVersions();
         indexScan.setCacheBlocks(false);
         return indexScan;
     }
@@ -1403,7 +1412,8 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
         if (filter instanceof PagedFilter) {
             PagedFilter pageFilter = (PagedFilter) filter;
             Filter delegateFilter = pageFilter.getDelegateFilter();
-            if (delegateFilter == null || delegateFilter instanceof FirstKeyOnlyFilter) {
+            if (!HbaseCompatCapabilities.isRawFilterSupported() &&
+                    (delegateFilter == null || delegateFilter instanceof FirstKeyOnlyFilter)) {
                 scan.setFilter(null);
                 return true;
             }
@@ -1431,7 +1441,7 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
             Scan incrScan = new Scan(scan);
             incrScan.setTimeRange(minTimestamp, scan.getTimeRange().getMax());
             incrScan.setRaw(true);
-            incrScan.setMaxVersions();
+            incrScan.readAllVersions();
             incrScan.getFamilyMap().clear();
             incrScan.setCacheBlocks(false);
             for (byte[] family : scan.getFamilyMap().keySet()) {
@@ -1442,16 +1452,17 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
                 incrScan.setStartRow(nextStartKey);
             }
             List<KeyRange> keys = new ArrayList<>();
-            try(RegionScanner scanner = new PagedRegionScanner(region, region.getScanner(incrScan), incrScan)) {
+            try (RegionScanner scanner = new PagedRegionScanner(region, region.getScanner(incrScan), incrScan)) {
                 List<Cell> row = new ArrayList<>();
                 int rowCount = 0;
                 // collect row keys that have been modified in the given time-range
                 // up to the size of page to build skip scan filter
                 do {
-                    ungroupedAggregateRegionObserver.checkForRegionClosing();
+                    ungroupedAggregateRegionObserver.checkForRegionClosingOrSplitting();
                     hasMoreIncr = scanner.nextRaw(row);
                     if (!row.isEmpty()) {
                         if (isDummy(row)) {
+                            row.clear();
                             continue;
                         }
                         keys.add(PVarbinary.INSTANCE.getKeyRange(CellUtil.cloneRow(row.get(0))));
