@@ -17,12 +17,6 @@
  */
 package org.apache.phoenix.index;
 
-import static org.apache.phoenix.compat.hbase.CompatUtil.setSingleRow;
-import static org.apache.phoenix.compat.hbase.CompatUtil.setStartRow;
-import static org.apache.phoenix.coprocessor.BaseScannerRegionObserver.CHECK_VERIFY_COLUMN;
-import static org.apache.phoenix.coprocessor.BaseScannerRegionObserver.EMPTY_COLUMN_FAMILY_NAME;
-import static org.apache.phoenix.coprocessor.BaseScannerRegionObserver.EMPTY_COLUMN_QUALIFIER_NAME;
-import static org.apache.phoenix.coprocessor.BaseScannerRegionObserver.PHYSICAL_DATA_TABLE_NAME;
 import static org.apache.phoenix.hbase.index.IndexRegionObserver.VERIFIED_BYTES;
 import static org.apache.phoenix.index.IndexMaintainer.getIndexMaintainer;
 import static org.apache.phoenix.schema.types.PDataType.TRUE_BYTES;
@@ -34,22 +28,24 @@ import java.io.IOException;
 import java.sql.SQLException;
 import java.util.Iterator;
 import java.util.List;
-import java.util.Random;
+import java.util.Optional;
 
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.CoprocessorEnvironment;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
-import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.HRegionInfo;
+import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Delete;
 import org.apache.hadoop.hbase.client.Mutation;
+import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.coprocessor.ObserverContext;
+import org.apache.hadoop.hbase.coprocessor.RegionCoprocessor;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
+import org.apache.hadoop.hbase.coprocessor.RegionObserver;
 import org.apache.hadoop.hbase.filter.Filter;
 import org.apache.hadoop.hbase.filter.FilterList;
 import org.apache.hadoop.hbase.filter.PageFilter;
@@ -64,8 +60,6 @@ import org.apache.phoenix.filter.PagedFilter;
 import org.apache.phoenix.hbase.index.covered.update.ColumnReference;
 import org.apache.phoenix.hbase.index.metrics.GlobalIndexCheckerSource;
 import org.apache.phoenix.hbase.index.metrics.MetricsIndexerSourceFactory;
-import org.apache.phoenix.hbase.index.table.HTableFactory;
-import org.apache.phoenix.hbase.index.util.ImmutableBytesPtr;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.query.QueryServicesOptions;
 import org.apache.phoenix.schema.SortOrder;
@@ -76,7 +70,6 @@ import org.apache.phoenix.util.ServerUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-
 /**
  * 
  * Coprocessor that verifies the scanned rows of a non-transactional global index.
@@ -100,13 +93,11 @@ import org.slf4j.LoggerFactory;
  * the verified version that is masked by the unverified version(s).
  *
  */
-public class GlobalIndexChecker extends BaseScannerRegionObserver {
-    private static final Logger LOG = LoggerFactory.getLogger(GlobalIndexChecker.class);
-    private static final String REPAIR_LOGGING_PERCENT_ATTRIB = "phoenix.index.repair.logging.percent";
-    private static final double DEFAULT_REPAIR_LOGGING_PERCENT = 1;
-
-    private HTableFactory hTableFactory;
+public class GlobalIndexChecker extends BaseScannerRegionObserver implements RegionCoprocessor{
+    private static final Logger LOG =
+        LoggerFactory.getLogger(GlobalIndexChecker.class);
     private GlobalIndexCheckerSource metricsSource;
+    private CoprocessorEnvironment env;
 
     public enum RebuildReturnCode {
         NO_DATA_ROW(0),
@@ -149,8 +140,6 @@ public class GlobalIndexChecker extends BaseScannerRegionObserver {
         private long pageSize = Long.MAX_VALUE;
         private boolean restartScanDueToPageFilterRemoval = false;
         private boolean hasMore;
-        private double loggingPercent;
-        private Random random;
         private String indexName;
         private long pageSizeMs;
 
@@ -182,9 +171,6 @@ public class GlobalIndexChecker extends BaseScannerRegionObserver {
                         "repairIndexRows: IndexMaintainer is not included in scan attributes for " +
                                 region.getRegionInfo().getTable().getNameAsString());
             }
-            loggingPercent = env.getConfiguration().getDouble(REPAIR_LOGGING_PERCENT_ATTRIB,
-                    DEFAULT_REPAIR_LOGGING_PERCENT);
-            random = new Random(EnvironmentEdgeManager.currentTimeMillis());
             pageSizeMs = getPageSizeMsForRegionScanner(scan);
         }
 
@@ -266,7 +252,7 @@ public class GlobalIndexChecker extends BaseScannerRegionObserver {
         }
 
         @Override
-        public HRegionInfo getRegionInfo() {
+        public RegionInfo getRegionInfo() {
             return scanner.getRegionInfo();
         }
 
@@ -293,7 +279,7 @@ public class GlobalIndexChecker extends BaseScannerRegionObserver {
                             IndexMaintainer.DeleteType.ALL_VERSIONS, ts);
                 }
                 Mutation[] mutations = new Mutation[]{del};
-                region.batchMutate(mutations, HConstants.NO_NONCE, HConstants.NO_NONCE);
+                region.batchMutate(mutations);
             }
         }
 
@@ -345,7 +331,11 @@ public class GlobalIndexChecker extends BaseScannerRegionObserver {
                 indexScan = new Scan(scan);
                 singleRowIndexScan = new Scan(scan);
                 byte[] dataTableName = scan.getAttribute(PHYSICAL_DATA_TABLE_NAME);
-                dataHTable = hTableFactory.getTable(new ImmutableBytesPtr(dataTableName));
+                dataHTable =
+                    ServerUtil.ConnectionFactory.
+                        getConnection(ServerUtil.ConnectionType.INDEX_WRITER_CONNECTION, env).
+                        getTable(TableName.valueOf(dataTableName));
+
                 viewConstants = IndexUtil.deserializeViewConstantsFromScan(scan);
                 // The following attributes are set to instruct UngroupedAggregateRegionObserver to do partial index rebuild
                 // i.e., rebuild a subset of index rows.
@@ -362,7 +352,8 @@ public class GlobalIndexChecker extends BaseScannerRegionObserver {
             // Rebuild the index row from the corresponding the row in the the data table
             // Get the data row key from the index row key
             byte[] dataRowKey = indexMaintainer.buildDataRowKey(new ImmutableBytesWritable(indexRowKey), viewConstants);
-            setSingleRow(buildIndexScan, dataRowKey);
+            buildIndexScan.withStartRow(dataRowKey, true);
+            buildIndexScan.withStopRow(dataRowKey, true);
             buildIndexScan.setTimeRange(0, maxTimestamp);
             // Pass the index row key to the partial index builder which will rebuild the index row and check if the
             // row key of this rebuilt index row matches with the passed index row key
@@ -386,7 +377,7 @@ public class GlobalIndexChecker extends BaseScannerRegionObserver {
                 row.clear();
                 if (restartScanDueToPageFilterRemoval) {
                     scanner.close();
-                    setStartRow(indexScan, indexRowKey, false);
+                    indexScan.withStartRow(indexRowKey, false);
                     scanner = ((BaseRegionScanner)delegate).getNewRegionScanner(indexScan);
                     hasMore = true;
                     // Set restartScanDueToPageFilterRemoval to false as we do not restart the scan unnecessarily next time
@@ -404,7 +395,7 @@ public class GlobalIndexChecker extends BaseScannerRegionObserver {
                 // Delete the unverified row from index if it is old enough
                 deleteRowIfAgedEnough(indexRowKey, ts, false);
                 // Open a new scanner starting from the row after the current row
-                setStartRow(indexScan, indexRowKey, false);
+                indexScan.withStartRow(indexRowKey, false);
                 scanner = ((BaseRegionScanner)delegate).getNewRegionScanner(indexScan);
                 hasMore = true;
                 // Skip this unverified row (i.e., do not return it to the client). Just retuning empty row is
@@ -414,7 +405,7 @@ public class GlobalIndexChecker extends BaseScannerRegionObserver {
             }
             // code == RebuildReturnCode.INDEX_ROW_EXISTS.getValue()
             // Open a new scanner starting from the current row
-            setStartRow(indexScan, indexRowKey, true);
+            indexScan.withStartRow(indexRowKey, true);
             scanner = ((BaseRegionScanner)delegate).getNewRegionScanner(indexScan);
             hasMore = scanner.next(row);
             if (row.isEmpty()) {
@@ -457,7 +448,8 @@ public class GlobalIndexChecker extends BaseScannerRegionObserver {
                 // Now we will do a single row scan to retrieve the verified index row built from the data table row.
                 // Note we cannot read all versions in one scan as the max number of row versions for an index table
                 // can be 1. In that case, we will get only one (i.e., the most recent) version instead of all versions
-                setSingleRow(singleRowIndexScan, indexRowKey);
+                singleRowIndexScan.withStartRow(indexRowKey, true);
+                singleRowIndexScan.withStopRow(indexRowKey, true);
                 singleRowIndexScan.setTimeRange(minTimestamp, ts);
                 RegionScanner singleRowScanner = ((BaseRegionScanner)delegate).getNewRegionScanner(singleRowIndexScan);
                 row.clear();
@@ -595,28 +587,17 @@ public class GlobalIndexChecker extends BaseScannerRegionObserver {
                 long ts = cellList.get(0).getTimestamp();
                 cellList.clear();
 
-                long repairTime;
                 try {
                     repairIndexRows(rowKey, ts, cellList);
-                    repairTime = EnvironmentEdgeManager.currentTimeMillis() - repairStart;
                     metricsSource.incrementIndexRepairs(indexName);
                     metricsSource.updateUnverifiedIndexRowAge(indexName,
                         EnvironmentEdgeManager.currentTimeMillis() - ts);
                     metricsSource.updateIndexRepairTime(indexName,
                         EnvironmentEdgeManager.currentTimeMillis() - repairStart);
-                    if (shouldLog()) {
-                        LOG.info("Index row repair on region {} took {} ms.",
-                                env.getRegionInfo().getRegionNameAsString(), repairTime);
-                    }
                 } catch (IOException e) {
-                    repairTime = EnvironmentEdgeManager.currentTimeMillis() - repairStart;
                     metricsSource.incrementIndexRepairFailures(indexName);
                     metricsSource.updateIndexRepairFailureTime(indexName,
                         EnvironmentEdgeManager.currentTimeMillis() - repairStart);
-                    if (shouldLog()) {
-                        LOG.warn("Index row repair failure on region {} took {} ms.",
-                                env.getRegionInfo().getRegionNameAsString(), repairTime);
-                    }
                     throw e;
                 }
 
@@ -627,13 +608,6 @@ public class GlobalIndexChecker extends BaseScannerRegionObserver {
                 return true;
             }
         }
-
-        private boolean shouldLog() {
-            if (loggingPercent == 0) {
-                return false;
-            }
-            return (random.nextDouble() <= (loggingPercent / 100.0d));
-        }
     }
 
     @Override
@@ -648,13 +622,14 @@ public class GlobalIndexChecker extends BaseScannerRegionObserver {
     }
 
     @Override
-    public void start(CoprocessorEnvironment e) throws IOException {
-        this.hTableFactory = ServerUtil.getDelegateHTableFactory(e, ServerUtil.ConnectionType.INDEX_WRITER_CONNECTION);
-        this.metricsSource = MetricsIndexerSourceFactory.getInstance().getGlobalIndexCheckerSource();
+    public Optional<RegionObserver> getRegionObserver() {
+        return Optional.of(this);
     }
 
     @Override
-    public void stop(CoprocessorEnvironment e) throws IOException {
-        this.hTableFactory.shutdown();
+    public void start(CoprocessorEnvironment e) throws IOException {
+        this.env = e;
+        this.metricsSource = MetricsIndexerSourceFactory.getInstance().getGlobalIndexCheckerSource();
     }
+
 }
