@@ -21,18 +21,16 @@ package org.apache.phoenix.iterate;
 import static org.apache.phoenix.coprocessor.ScanRegionObserver.WILDCARD_SCAN_INCLUDES_DYNAMIC_COLUMNS;
 import static org.apache.phoenix.schema.types.PDataType.TRUE_BYTES;
 import static org.apache.phoenix.util.ScanUtil.getDummyResult;
-import org.apache.phoenix.util.EnvironmentEdgeManager;
-
 import static org.apache.phoenix.util.ScanUtil.getPageSizeMsForRegionScanner;
 import static org.apache.phoenix.util.ScanUtil.isDummy;
 
-import com.google.common.collect.ImmutableList;
+import org.apache.hadoop.hbase.CellUtil;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableList;
 
 import org.apache.hadoop.hbase.Cell;
-import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.HRegionInfo;
 import org.apache.hadoop.hbase.KeyValue;
+import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
@@ -43,12 +41,9 @@ import org.apache.hadoop.hbase.regionserver.ScannerContext;
 import org.apache.hadoop.hbase.regionserver.ScannerContextUtil;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.Pair;
-import org.apache.hadoop.io.WritableUtils;
-import org.apache.phoenix.coprocessor.BaseScannerRegionObserver;
 import org.apache.phoenix.coprocessor.generated.DynamicColumnMetaDataProtos;
 import org.apache.phoenix.execute.TupleProjector;
 import org.apache.phoenix.expression.Expression;
-import org.apache.phoenix.expression.ExpressionType;
 import org.apache.phoenix.expression.KeyValueColumnExpression;
 import org.apache.phoenix.hbase.index.covered.update.ColumnReference;
 import org.apache.phoenix.index.IndexMaintainer;
@@ -68,8 +63,6 @@ import org.apache.phoenix.util.IndexUtil;
 import org.apache.phoenix.util.ScanUtil;
 import org.apache.phoenix.util.ServerUtil;
 
-import java.io.ByteArrayInputStream;
-import java.io.DataInputStream;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
@@ -127,34 +120,10 @@ public abstract class RegionScannerFactory {
       final ImmutableBytesWritable ptr, final boolean useQualifierAsListIndex) {
     return new RegionScanner() {
 
-      private HRegionInfo regionInfo = env.getRegionInfo();
+      private RegionInfo regionInfo = env.getRegionInfo();
       private byte[] actualStartKey = getActualStartKey();
       private boolean useNewValueColumnQualifier = EncodedColumnsUtil.useNewValueColumnQualifier(scan);
       final long pageSizeMs = getPageSizeMsForRegionScanner(scan);
-      Expression extraWhere = null;
-      long extraLimit = -1;
-
-      {
-          // for local indexes construct the row filter for uncovered columns if it exists
-          if (ScanUtil.isLocalIndex(scan)) {
-              byte[] expBytes = scan.getAttribute(BaseScannerRegionObserver.LOCAL_INDEX_FILTER);
-              if (expBytes != null) {
-                  try {
-                      ByteArrayInputStream stream = new ByteArrayInputStream(expBytes);
-                      DataInputStream input = new DataInputStream(stream);
-                      extraWhere = ExpressionType.values()[WritableUtils.readVInt(input)].newInstance();
-                      extraWhere.readFields(input);
-                  } catch (IOException io) {
-                      // should not happen since we're reading from a byte[]
-                      throw new RuntimeException(io);
-                  }
-              }
-              byte[] limitBytes = scan.getAttribute(BaseScannerRegionObserver.LOCAL_INDEX_LIMIT);
-              if (limitBytes != null) {
-                  extraLimit = Bytes.toLong(limitBytes);
-              }
-          }
-      }
 
       // Get the actual scan start row of local index. This will be used to compare the row
       // key of the results less than scan start row when there are references.
@@ -188,7 +157,7 @@ public abstract class RegionScannerFactory {
       }
 
       @Override
-      public HRegionInfo getRegionInfo() {
+      public RegionInfo getRegionInfo() {
         return s.getRegionInfo();
       }
 
@@ -236,17 +205,6 @@ public abstract class RegionScannerFactory {
              */
             IndexUtil.wrapResultUsingOffset(env, result, offset, dataColumns,
                 tupleProjector, dataRegion, indexMaintainer, viewConstants, ptr);
-
-            if (extraWhere != null) {
-                Tuple merged = useQualifierAsListIndex ? new PositionBasedResultTuple(result) :
-                    new ResultTuple(Result.create(result));
-                ImmutableBytesWritable ptr = new ImmutableBytesWritable();
-                extraWhere.evaluate(merged, ptr);
-                if (!Boolean.TRUE.equals(extraWhere.getDataType().toObject(ptr))) {
-                    result.clear();
-                    return next;
-                }
-            }
           }
           if (projector != null) {
             Tuple toProject = useQualifierAsListIndex ? new PositionBasedResultTuple(result) :
@@ -264,9 +222,6 @@ public abstract class RegionScannerFactory {
               result.add(arrayElementCell);
             }
           }
-          if (extraLimit >= 0 && --extraLimit == 0) {
-              return false;
-          }
           // There is a scanattribute set to retrieve the specific array element
           return next;
         } catch (Throwable t) {
