@@ -29,19 +29,22 @@ import java.util.UUID;
 
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.CommandLine;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.CommandLineParser;
+import org.apache.phoenix.thirdparty.org.apache.commons.cli.DefaultParser;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.HelpFormatter;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.Option;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.Options;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.ParseException;
-import org.apache.phoenix.thirdparty.org.apache.commons.cli.PosixParser;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.conf.Configured;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hbase.HBaseConfiguration;
 import org.apache.hadoop.hbase.KeyValue;
-import org.apache.hadoop.hbase.client.HTable;
+import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.ConnectionFactory;
+import org.apache.hadoop.hbase.client.RegionLocator;
+import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
-import org.apache.hadoop.hbase.mapreduce.LoadIncrementalHFiles;
+import org.apache.hadoop.hbase.tool.LoadIncrementalHFiles;
 import org.apache.hadoop.mapreduce.Job;
 import org.apache.hadoop.mapreduce.lib.input.FileInputFormat;
 import org.apache.hadoop.mapreduce.lib.output.FileOutputFormat;
@@ -64,9 +67,9 @@ import org.apache.phoenix.util.StringUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Preconditions;
-import com.google.common.base.Splitter;
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.base.Preconditions;
+import org.apache.phoenix.thirdparty.com.google.common.base.Splitter;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 /**
  * Base tool for running MapReduce-based ingests of data.
@@ -123,7 +126,7 @@ public abstract class AbstractBulkLoadTool extends Configured implements Tool {
 
         Options options = getOptions();
 
-        CommandLineParser parser = new PosixParser();
+        CommandLineParser parser = new DefaultParser();
         CommandLine cmdLine = null;
         try {
             cmdLine = parser.parse(options, args);
@@ -319,55 +322,64 @@ public abstract class AbstractBulkLoadTool extends Configured implements Tool {
         job.setOutputValueClass(KeyValue.class);
         job.setReducerClass(FormatToKeyValueReducer.class);
         byte[][] splitKeysBeforeJob = null;
-        HTable table = null;
-        if(hasLocalIndexes) {
-            try{
-                table = new HTable(job.getConfiguration(), qualifiedTableName);
-                splitKeysBeforeJob = table.getRegionLocator().getStartKeys();
-            } finally {
-                if(table != null )table.close();
-            }
-        }
-        MultiHfileOutputFormat.configureIncrementalLoad(job, tablesToBeLoaded);
-
-        final String tableNamesAsJson = TargetTableRefFunctions.NAMES_TO_JSON.apply(tablesToBeLoaded);
-        final String logicalNamesAsJson = TargetTableRefFunctions.LOGICAL_NAMES_TO_JSON.apply(tablesToBeLoaded);
-
-        job.getConfiguration().set(FormatToBytesWritableMapper.TABLE_NAMES_CONFKEY,tableNamesAsJson);
-        job.getConfiguration().set(FormatToBytesWritableMapper.LOGICAL_NAMES_CONFKEY,logicalNamesAsJson);
-
-        // give subclasses their hook
-        setupJob(job);
-
-        LOGGER.info("Running MapReduce import job from {} to {}", inputPaths, outputPath);
-        boolean success = job.waitForCompletion(true);
-
-        if (success) {
-            if (hasLocalIndexes) {
-                try {
-                    table = new HTable(job.getConfiguration(), qualifiedTableName);
-                    if(!IndexUtil.matchingSplitKeys(splitKeysBeforeJob, table.getRegionLocator().getStartKeys())) {
-                        LOGGER.error("The table "
-                                + qualifiedTableName
-                                + " has local indexes and there is split key mismatch before and"
-                                + " after running bulkload job. Please rerun the job otherwise"
-                                + " there may be inconsistencies between actual data and index data.");
-                        return -1;
-                    }
+        try(org.apache.hadoop.hbase.client.Connection hbaseConn =
+                ConnectionFactory.createConnection(job.getConfiguration())) {
+            RegionLocator regionLocator = null;
+            if(hasLocalIndexes) {
+                try{
+                    regionLocator = hbaseConn.getRegionLocator(
+                            TableName.valueOf(qualifiedTableName));
+                    splitKeysBeforeJob = regionLocator.getStartKeys();
                 } finally {
-                    if (table != null) table.close();
+                    if (regionLocator != null) regionLocator.close();
                 }
             }
-            LOGGER.info("Loading HFiles from {}", outputPath);
-            completebulkload(conf,outputPath,tablesToBeLoaded);
-            LOGGER.info("Removing output directory {}", outputPath);
-            if(!outputPath.getFileSystem(conf).delete(outputPath, true)) {
-                LOGGER.error("Failed to delete the output directory {}", outputPath);
-            }
-            return 0;
-        } else {
-            return -1;
-        }
+            MultiHfileOutputFormat.configureIncrementalLoad(job, tablesToBeLoaded);
+
+            final String tableNamesAsJson = TargetTableRefFunctions.NAMES_TO_JSON
+                    .apply(tablesToBeLoaded);
+            final String logicalNamesAsJson = TargetTableRefFunctions.LOGICAL_NAMES_TO_JSON
+                    .apply(tablesToBeLoaded);
+
+            job.getConfiguration().set(FormatToBytesWritableMapper.TABLE_NAMES_CONFKEY,
+                    tableNamesAsJson);
+            job.getConfiguration().set(FormatToBytesWritableMapper.LOGICAL_NAMES_CONFKEY,
+                    logicalNamesAsJson);
+
+            // give subclasses their hook
+            setupJob(job);
+
+            LOGGER.info("Running MapReduce import job from {} to {}", inputPaths, outputPath);
+            boolean success = job.waitForCompletion(true);
+
+            if (success) {
+                if (hasLocalIndexes) {
+                    try {
+                        regionLocator = hbaseConn.getRegionLocator(
+                                TableName.valueOf(qualifiedTableName));
+                        if(!IndexUtil.matchingSplitKeys(splitKeysBeforeJob,
+                                regionLocator.getStartKeys())) {
+                            LOGGER.error("The table " + qualifiedTableName + " has local indexes and"
+                                    + " there is split key mismatch before and after running"
+                                    + " bulkload job. Please rerun the job otherwise there may be"
+                                    + " inconsistencies between actual data and index data.");
+                            return -1;
+                        }
+                    } finally {
+                        if (regionLocator != null) regionLocator.close();
+                    }
+                }
+                LOGGER.info("Loading HFiles from {}", outputPath);
+                completebulkload(conf,outputPath,tablesToBeLoaded);
+                LOGGER.info("Removing output directory {}", outputPath);
+                if(!outputPath.getFileSystem(conf).delete(outputPath, true)) {
+                    LOGGER.error("Failed to delete the output directory {}", outputPath);
+                }
+                return 0;
+            } else {
+               return -1;
+           }
+       }
     }
 
     private void completebulkload(Configuration conf,Path outputPath , List<TargetTableRef> tablesToBeLoaded) throws Exception {
@@ -380,9 +392,12 @@ public abstract class AbstractBulkLoadTool extends Configured implements Tool {
             LoadIncrementalHFiles loader = new LoadIncrementalHFiles(conf);
             String tableName = table.getPhysicalName();
             Path tableOutputPath = CsvBulkImportUtil.getOutputPath(outputPath, tableName);
-            try(HTable htable = new HTable(conf,tableName)) {
+            try(org.apache.hadoop.hbase.client.Connection hbaseConn =
+                    ConnectionFactory.createConnection(conf);
+                    Table htable = hbaseConn.getTable(TableName.valueOf(tableName))) {
                 LOGGER.info("Loading HFiles for {} from {}", tableName , tableOutputPath);
-                loader.doBulkLoad(tableOutputPath, htable);
+                loader.doBulkLoad(tableOutputPath, hbaseConn.getAdmin(), htable,
+                        hbaseConn.getRegionLocator(TableName.valueOf(tableName)));
                 LOGGER.info("Incremental load complete for table=" + tableName);
             }
         }
