@@ -33,8 +33,6 @@ import javax.annotation.Nullable;
 
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
-import org.apache.hadoop.hbase.KeyValue;
-import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.Pair;
@@ -57,18 +55,17 @@ import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.QueryUtil;
 import org.apache.phoenix.util.SchemaUtil;
 import org.apache.phoenix.util.UpsertExecutor;
-import org.apache.phoenix.hbase.index.IndexRegionObserver;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.annotations.VisibleForTesting;
-import com.google.common.base.Function;
-import com.google.common.base.Joiner;
-import com.google.common.base.Splitter;
-import com.google.common.base.Throwables;
-import com.google.common.collect.ImmutableList;
-import com.google.common.collect.Iterables;
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
+import org.apache.phoenix.thirdparty.com.google.common.base.Function;
+import org.apache.phoenix.thirdparty.com.google.common.base.Joiner;
+import org.apache.phoenix.thirdparty.com.google.common.base.Splitter;
+import org.apache.phoenix.thirdparty.com.google.common.base.Throwables;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableList;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Iterables;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 /**
  * Base class for converting some input source format into {@link ImmutableBytesWritable}s that
@@ -79,8 +76,7 @@ import com.google.common.collect.Lists;
 public abstract class FormatToBytesWritableMapper<RECORD> extends Mapper<LongWritable, Text, TableRowkeyPair,
         ImmutableBytesWritable> {
 
-    protected static final Logger LOGGER =
-            LoggerFactory.getLogger(FormatToBytesWritableMapper.class);
+    protected static final Logger LOGGER = LoggerFactory.getLogger(FormatToBytesWritableMapper.class);
 
     protected static final String COUNTER_GROUP_NAME = "Phoenix MapReduce Import";
 
@@ -109,7 +105,6 @@ public abstract class FormatToBytesWritableMapper<RECORD> extends Mapper<LongWri
     protected PhoenixConnection conn;
     protected UpsertExecutor<RECORD, ?> upsertExecutor;
     protected ImportPreUpsertKeyValueProcessor preUpdateProcessor;
-    protected IndexStatusUpdater[] indexStatusUpdaters;
     protected List<String> tableNames;
     protected List<String> logicalNames;
     protected MapperUpsertListener<RECORD> upsertListener;
@@ -155,7 +150,6 @@ public abstract class FormatToBytesWritableMapper<RECORD> extends Mapper<LongWri
         preUpdateProcessor = PhoenixConfigurationUtil.loadPreUpsertProcessor(conf);
     }
 
-    @SuppressWarnings("deprecation")
     @Override
     protected void map(LongWritable key, Text value, Context context) throws IOException,
             InterruptedException {
@@ -176,32 +170,31 @@ public abstract class FormatToBytesWritableMapper<RECORD> extends Mapper<LongWri
                 return;
             }
             upsertExecutor.execute(ImmutableList.<RECORD>of(record));
-            Map<Integer, List<KeyValue>> map = new HashMap<>();
-            Iterator<Pair<byte[], List<KeyValue>>> uncommittedDataIterator
+            Map<Integer, List<Cell>> map = new HashMap<>();
+            Iterator<Pair<byte[], List<Cell>>> uncommittedDataIterator
                     = PhoenixRuntime.getUncommittedDataIterator(conn, true);
             while (uncommittedDataIterator.hasNext()) {
-                Pair<byte[], List<KeyValue>> kvPair = uncommittedDataIterator.next();
-                List<KeyValue> keyValueList = kvPair.getSecond();
-                byte[] tableName = kvPair.getFirst();
-                keyValueList = preUpdateProcessor.preUpsert(tableName, keyValueList);
+                Pair<byte[], List<Cell>> kvPair = uncommittedDataIterator.next();
+                List<Cell> keyValueList = kvPair.getSecond();
+                keyValueList = preUpdateProcessor.preUpsert(kvPair.getFirst(), keyValueList);
+                byte[] first = kvPair.getFirst();
                 // Create a list of KV for each table
                 for (int i = 0; i < tableNames.size(); i++) {
-                    if (Bytes.compareTo(Bytes.toBytes(tableNames.get(i)), tableName) == 0) {
+                    if (Bytes.compareTo(Bytes.toBytes(tableNames.get(i)), first) == 0) {
                         if (!map.containsKey(i)) {
-                            map.put(i, new ArrayList<KeyValue>());
+                            map.put(i, new ArrayList<Cell>());
                         }
-                        List<KeyValue> cellsForTable = map.get(i);
-                        if (indexStatusUpdaters[i] != null) {
-                            indexStatusUpdaters[i].setVerfied(keyValueList);
+                        List<Cell> list = map.get(i);
+                        for (Cell kv : keyValueList) {
+                            list.add(kv);
                         }
-                        cellsForTable.addAll(keyValueList);
                         break;
                     }
                 }
             }
-            for (Map.Entry<Integer, List<KeyValue>> rowEntry : map.entrySet()) {
+            for (Map.Entry<Integer, List<Cell>> rowEntry : map.entrySet()) {
                 int tableIndex = rowEntry.getKey();
-                List<KeyValue> lkv = rowEntry.getValue();
+                List<Cell> lkv = rowEntry.getValue();
                 // All KV values combines to a single byte array
                 writeAggregatedRow(context, tableNames.get(tableIndex), lkv);
             }
@@ -217,7 +210,6 @@ public abstract class FormatToBytesWritableMapper<RECORD> extends Mapper<LongWri
      */
     private void initColumnIndexes() throws SQLException {
         columnIndexes = new TreeMap<>(Bytes.BYTES_COMPARATOR);
-        indexStatusUpdaters = new IndexStatusUpdater[logicalNames.size()];
         int columnIndex = 0;
         for (int index = 0; index < logicalNames.size(); index++) {
             PTable table = PhoenixRuntime.getTable(conn, logicalNames.get(index));
@@ -254,10 +246,6 @@ public abstract class FormatToBytesWritableMapper<RECORD> extends Mapper<LongWri
             byte[] cfn = Bytes.add(emptyColumnFamily, QueryConstants.NAMESPACE_SEPARATOR_BYTES, emptyKeyValue);
             columnIndexes.put(cfn, new Integer(columnIndex));
             columnIndex++;
-            if (PTable.IndexType.GLOBAL == table.getIndexType()) {
-                indexStatusUpdaters[index] =
-                        new IndexStatusUpdater(emptyColumnFamily, emptyKeyValue);
-            }
         }
     }
 
@@ -291,13 +279,13 @@ public abstract class FormatToBytesWritableMapper<RECORD> extends Mapper<LongWri
      * @throws InterruptedException
      */
 
-    private void writeAggregatedRow(Context context, String tableName, List<KeyValue> lkv)
+    private void writeAggregatedRow(Context context, String tableName, List<Cell> lkv)
             throws IOException, InterruptedException {
         ByteArrayOutputStream bos = new ByteArrayOutputStream(1024);
         DataOutputStream outputStream = new DataOutputStream(bos);
         ImmutableBytesWritable outputKey =null;
         if (!lkv.isEmpty()) {
-            for (KeyValue cell : lkv) {
+            for (Cell cell : lkv) {
                 if (outputKey == null || Bytes.compareTo(outputKey.get(), outputKey.getOffset(),
                         outputKey.getLength(), cell.getRowArray(), cell.getRowOffset(), cell
                                 .getRowLength()) != 0) {
@@ -423,46 +411,8 @@ public abstract class FormatToBytesWritableMapper<RECORD> extends Mapper<LongWri
             ImportPreUpsertKeyValueProcessor {
 
         @Override
-        public List<KeyValue> preUpsert(byte[] tableName, List<KeyValue> keyValues) {
+        public List<Cell> preUpsert(byte[] rowKey, List<Cell> keyValues) {
             return keyValues;
         }
     }
-
-    /**
-     * Updates the EMPTY cell value to VERIFIED for global index table rows
-     */
-    private static class IndexStatusUpdater {
-
-        private final byte[] emptyKeyValueCF;
-        private final int emptyKeyValueCFLength;
-        private final byte[] emptyKeyValueQualifier;
-        private final int emptyKeyValueQualifierLength;
-
-        public IndexStatusUpdater(final byte[] emptyKeyValueCF, final byte[] emptyKeyValueQualifier) {
-            this.emptyKeyValueCF = emptyKeyValueCF;
-            this.emptyKeyValueQualifier = emptyKeyValueQualifier;
-            emptyKeyValueCFLength = emptyKeyValueCF.length;
-            emptyKeyValueQualifierLength = emptyKeyValueQualifier.length;
-        }
-
-        /**
-         * Update the Empty cell values to VERIFIED in the passed keyValues list
-         * 
-         * @param keyValues will be modified
-         */
-        public void setVerfied(List<KeyValue> keyValues) {
-            for (int i = 0; i < keyValues.size() ; i++) {
-                Cell kv = keyValues.get(i);
-                if (CellUtil.matchingFamily(kv, emptyKeyValueCF, 0, emptyKeyValueCFLength)
-                        && CellUtil.matchingQualifier(kv, emptyKeyValueQualifier, 0, emptyKeyValueQualifierLength)) {
-                    if (kv.getValueLength() != 1) {
-                        //This should never happen. Fail fast if it does.
-                       throw new IllegalArgumentException("Empty cell value length is not 1");
-                    }
-                    //We are directly overwriting the value for performance
-                    kv.getValueArray()[kv.getValueOffset()] = IndexRegionObserver.VERIFIED_BYTES[0];
-                }
-            }
-        }
-    }
 }
