@@ -37,8 +37,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.UUID;
 
-import com.google.common.annotations.VisibleForTesting;
-import com.google.common.base.Strings;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
+import org.apache.phoenix.thirdparty.com.google.common.base.Strings;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.CommandLine;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.CommandLineParser;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.DefaultParser;
@@ -46,7 +46,7 @@ import org.apache.phoenix.thirdparty.org.apache.commons.cli.HelpFormatter;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.Option;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.Options;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.ParseException;
-import org.apache.commons.lang.exception.ExceptionUtils;
+import org.apache.commons.lang3.exception.ExceptionUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.conf.Configured;
 import org.apache.hadoop.fs.FileSystem;
@@ -55,9 +55,9 @@ import org.apache.hadoop.hbase.HBaseConfiguration;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.ConnectionFactory;
 import org.apache.hadoop.hbase.client.Admin;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
-import org.apache.hadoop.hbase.client.HTable;
+import org.apache.hadoop.hbase.client.RegionLocator;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
@@ -66,7 +66,7 @@ import org.apache.hadoop.hbase.mapreduce.TableInputFormat;
 import org.apache.hadoop.hbase.mapreduce.TableMapReduceUtil;
 import org.apache.hadoop.hbase.mapreduce.TableOutputFormat;
 import org.apache.hadoop.hbase.util.Bytes;
-import org.apache.hadoop.hbase.util.FSUtils;
+import org.apache.hadoop.hbase.util.CommonFSUtils;
 import org.apache.hadoop.io.IntWritable;
 import org.apache.hadoop.io.NullWritable;
 import org.apache.hadoop.mapreduce.Job;
@@ -74,6 +74,7 @@ import org.apache.hadoop.mapreduce.lib.output.FileOutputFormat;
 import org.apache.hadoop.util.StringUtils;
 import org.apache.hadoop.util.Tool;
 import org.apache.hadoop.util.ToolRunner;
+import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
 import org.apache.phoenix.compile.PostIndexDDLCompiler;
 import org.apache.phoenix.coprocessor.BaseScannerRegionObserver;
 import org.apache.phoenix.hbase.index.ValueGetter;
@@ -113,7 +114,7 @@ import org.apache.phoenix.util.TransactionUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 /**
  * An MR job to populate the index table from the data table.
@@ -398,6 +399,11 @@ public class IndexTool extends Configured implements Tool {
                 "DisableLoggingType: ["
                 + cmdLine.getOptionValue(DISABLE_LOGGING_OPTION.getOpt()) + "]");
         }
+        if ((cmdLine.hasOption(START_TIME_OPTION.getOpt()) || cmdLine.hasOption(RETRY_VERIFY_OPTION.getOpt()))
+            && !HbaseCompatCapabilities.isRawFilterSupported()) {
+            throw new IllegalStateException("Can't do incremental index verification on this " +
+                "version of HBase because raw skip scan filters are not supported.");
+        }
         return cmdLine;
     }
 
@@ -655,7 +661,7 @@ public class IndexTool extends Configured implements Tool {
             if (!useSnapshot) {
                 PhoenixMapReduceUtil.setInput(job, PhoenixIndexDBWritable.class, dataTableWithSchema, selectQuery);
             } else {
-                HBaseAdmin admin = null;
+                Admin admin = null;
                 String snapshotName;
                 try {
                     admin = pConnection.getQueryServices().getAdmin();
@@ -669,8 +675,8 @@ public class IndexTool extends Configured implements Tool {
                 }
                 // root dir not a subdirectory of hbase dir
                 Path rootDir = new Path("hdfs:///index-snapshot-dir");
-                FSUtils.setRootDir(configuration, rootDir);
-                Path restoreDir = new Path(FSUtils.getRootDir(configuration), "restore-dir");
+                CommonFSUtils.setRootDir(configuration, rootDir);
+                Path restoreDir = new Path(CommonFSUtils.getRootDir(configuration), "restore-dir");
 
                 // set input for map reduce job using hbase snapshots
                 PhoenixMapReduceUtil
@@ -805,7 +811,7 @@ public class IndexTool extends Configured implements Tool {
                 if (shouldDeleteBeforeRebuild) {
                     deleteBeforeRebuild(conn);
                 }
-                preSplitIndexTable(cmdLine, conn, configuration);
+                preSplitIndexTable(cmdLine, conn);
             }
 
             boolean result = submitIndexToolJob(conn, configuration);
@@ -965,9 +971,12 @@ public class IndexTool extends Configured implements Tool {
         qIndexTable = SchemaUtil.getQualifiedTableName(schemaName, indexTable);
         if (IndexType.LOCAL.equals(indexType)) {
             isLocalIndexBuild = true;
-            HTable htable = (HTable)connection.unwrap(PhoenixConnection.class).getQueryServices()
-                    .getTable(pIndexTable.getPhysicalName().getBytes());
-                splitKeysBeforeJob = htable.getRegionLocator().getStartKeys();
+            try (org.apache.hadoop.hbase.client.Connection hConn
+                    = getTemporaryHConnection(connection.unwrap(PhoenixConnection.class))) {
+                RegionLocator regionLocator = hConn
+                        .getRegionLocator(TableName.valueOf(pIndexTable.getPhysicalName().getBytes()));
+                splitKeysBeforeJob = regionLocator.getStartKeys();
+            }
         }
         // We have to mark Disable index to Building before we can set it to Active in the reducer. Otherwise it errors out with
         // index state transition error
@@ -992,8 +1001,7 @@ public class IndexTool extends Configured implements Tool {
         }
     }
 
-    private void preSplitIndexTable(CommandLine cmdLine, Connection connection,
-            Configuration configuration)
+    private void preSplitIndexTable(CommandLine cmdLine, Connection connection)
             throws SQLException, IOException {
         boolean autosplit = cmdLine.hasOption(AUTO_SPLIT_INDEX_OPTION.getOpt());
         boolean splitIndex = cmdLine.hasOption(SPLIT_INDEX_OPTION.getOpt());
@@ -1003,9 +1011,9 @@ public class IndexTool extends Configured implements Tool {
             int autosplitNumRegions = nOpt == null ? DEFAULT_AUTOSPLIT_NUM_REGIONS : Integer.parseInt(nOpt);
             String rateOpt = cmdLine.getOptionValue(SPLIT_INDEX_OPTION.getOpt());
             double samplingRate = rateOpt == null ? DEFAULT_SPLIT_SAMPLING_RATE : Double.parseDouble(rateOpt);
-            LOGGER.info(String.format("Will split index %s , autosplit=%s ," +
-                            " autoSplitNumRegions=%s , samplingRate=%s", indexTable,
-                    autosplit, autosplitNumRegions, samplingRate));
+            LOGGER.info(String.format("Will split index %s , autosplit=%s ,"
+                            + " autoSplitNumRegions=%s , samplingRate=%s", indexTable, autosplit,
+                    autosplitNumRegions, samplingRate));
 
             splitIndexTable(connection.unwrap(PhoenixConnection.class), autosplit,
                     autosplitNumRegions, samplingRate);
@@ -1036,10 +1044,11 @@ public class IndexTool extends Configured implements Tool {
             int autosplitNumRegions, double samplingRate)
             throws SQLException, IOException, IllegalArgumentException {
         int numRegions;
-        try (HTable hDataTable =
-                (HTable) pConnection.getQueryServices()
-                        .getTable(pDataTable.getPhysicalName().getBytes())) {
-            numRegions = hDataTable.getRegionLocator().getStartKeys().length;
+
+        try (org.apache.hadoop.hbase.client.Connection tempHConn = getTemporaryHConnection(pConnection);
+                RegionLocator regionLocator =
+                        tempHConn.getRegionLocator(TableName.valueOf(qDataTable))) {
+            numRegions = regionLocator.getStartKeys().length;
             if (autosplit && (numRegions <= autosplitNumRegions)) {
                 LOGGER.info(String.format(
                     "Will not split index %s because the data table only has %s regions, autoSplitNumRegions=%s",
@@ -1059,7 +1068,7 @@ public class IndexTool extends Configured implements Tool {
         try (final PhoenixResultSet rs =
                 pConnection.createStatement().executeQuery(dataSampleQuery)
                         .unwrap(PhoenixResultSet.class);
-                HBaseAdmin admin = pConnection.getQueryServices().getAdmin()) {
+                Admin admin = pConnection.getQueryServices().getAdmin()) {
             EquiDepthStreamHistogram histo = new EquiDepthStreamHistogram(numRegions);
             ValueGetter getter = getIndexValueGetter(rs, dataColNames);
             // loop over data table rows - build the index rowkey, put it in the histogram
@@ -1086,6 +1095,13 @@ public class IndexTool extends Configured implements Tool {
         }
     }
 
+    private org.apache.hadoop.hbase.client.Connection getTemporaryHConnection(PhoenixConnection pConnection)
+            throws SQLException, IOException {
+        try (Admin admin = pConnection.getQueryServices().getAdmin()) {
+            return ConnectionFactory.createConnection(admin.getConfiguration());
+        }
+    }
+
     // setup a ValueGetter to get index values from the ResultSet
     private ValueGetter getIndexValueGetter(final PhoenixResultSet rs, List<String> dataColNames) {
         // map from data col name to index in ResultSet
@@ -1094,7 +1110,7 @@ public class IndexTool extends Configured implements Tool {
         for (String dataCol : dataColNames) {
             rsIndex.put(SchemaUtil.getEscapedFullColumnName(dataCol), i++);
         }
-        ValueGetter getter = new ValueGetter() {
+        return new ValueGetter() {
             final ImmutableBytesWritable valuePtr = new ImmutableBytesWritable();
             final ImmutableBytesWritable rowKeyPtr = new ImmutableBytesWritable();
 
@@ -1118,7 +1134,6 @@ public class IndexTool extends Configured implements Tool {
                 return ByteUtil.copyKeyBytesIfNecessary(rowKeyPtr);
             }
         };
-        return getter;
     }
 
     /**
@@ -1126,6 +1141,7 @@ public class IndexTool extends Configured implements Tool {
      * @param connection
      * @param masterTable
      * @param indexTable
+     * @param tenantId
      * @return
      * @throws SQLException
      */
