@@ -17,25 +17,27 @@
  */
 package org.apache.phoenix.mapreduce.index;
 
-import com.google.common.annotations.VisibleForTesting;
-import com.google.common.base.Strings;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
+import org.apache.phoenix.thirdparty.com.google.common.base.Strings;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.CommandLine;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.CommandLineParser;
+import org.apache.phoenix.thirdparty.org.apache.commons.cli.DefaultParser;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.HelpFormatter;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.Option;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.Options;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.ParseException;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.PosixParser;
-import org.apache.commons.lang.StringUtils;
 import org.apache.hadoop.conf.Configured;
 import org.apache.hadoop.hbase.HConstants;
-
-import org.apache.hadoop.hbase.HBaseConfiguration;
-import org.apache.hadoop.hbase.HTableDescriptor;
-import org.apache.hadoop.hbase.TableName;
-import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.CoprocessorDescriptorBuilder;
+import org.apache.hadoop.util.StringUtils;
 import org.apache.hadoop.util.Tool;
 import org.apache.hadoop.util.ToolRunner;
+
+import org.apache.hadoop.hbase.HBaseConfiguration;
+import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.phoenix.hbase.index.IndexRegionObserver;
 import org.apache.phoenix.hbase.index.Indexer;
 import org.apache.phoenix.hbase.index.covered.NonTxIndexBuilder;
@@ -48,6 +50,7 @@ import org.apache.phoenix.query.ConnectionQueryServices;
 
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.query.QueryServicesOptions;
+import org.apache.phoenix.schema.PIndexState;
 import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.schema.PTableType;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
@@ -118,6 +121,7 @@ public class IndexUpgradeTool extends Configured implements Tool {
     private IndexTool indexingTool;
 
     private HashMap<String, HashSet<String>> tablesAndIndexes = new HashMap<>();
+    private HashMap<String, HashMap<String,IndexInfo>> rebuildMap = new HashMap<>();
     private HashMap<String, String> prop = new  HashMap<>();
     private HashMap<String, String> emptyProp = new HashMap<>();
 
@@ -126,10 +130,10 @@ public class IndexUpgradeTool extends Configured implements Tool {
     private String inputTables;
     private String logFile;
     private String inputFile;
+    private boolean isWaitComplete = false;
     private String indexToolOpts;
 
     private boolean test = false;
-    private boolean isWaitComplete = false;
     private boolean failUpgradeTask = false;
     private boolean failDowngradeTask = false;
     private boolean hasFailure = false;
@@ -199,7 +203,7 @@ public class IndexUpgradeTool extends Configured implements Tool {
         CommandLine cmdLine = null;
         try {
             cmdLine = parseOptions(args);
-            LOGGER.info("Index Upgrade tool initiated: " + StringUtils.join( args, ","));
+            LOGGER.info("Index Upgrade tool initiated: " + String.join(",", args));
         } catch (IllegalStateException e) {
             printHelpAndExit(e.getMessage(), getOptions());
         }
@@ -435,7 +439,7 @@ public class IndexUpgradeTool extends Configured implements Tool {
                         + " (immutable)");
                 disableTable(admin, dataTableFullName, indexes);
                 modifyTable(admin, dataTableFullName, indexes);
-            } catch (IOException | SQLException | RuntimeException e) {
+            } catch (Throwable e) {
                 LOGGER.severe("Something went wrong while disabling "
                         + "or modifying immutable table " + e);
                 handleFailure(queryServices, dataTableFullName, immutableList, failedTables);
@@ -541,15 +545,15 @@ public class IndexUpgradeTool extends Configured implements Tool {
                 tablesAndIndexes.remove(dataTableFullName);
                 immutableList.remove(dataTableFullName);
                 throw new RuntimeException("Manually enable the following tables "
-                    + getSubListString(immutableList, dataTableFullName)
-                    + " and run the index rebuild ", e);
+                        + getSubListString(immutableList, dataTableFullName)
+                        + " and run the index rebuild ", e);
             }
         }
     }
 
     private String getSubListString(List<String> tableList, String dataTableFullName) {
-        return StringUtils.join(tableList.subList(tableList.indexOf(dataTableFullName),
-                tableList.size()), ",");
+        return StringUtils.join(",", tableList.subList(tableList.indexOf(dataTableFullName),
+                tableList.size()));
     }
 
     private long getWaitMoreTime(long startWaitTime) {
@@ -569,7 +573,7 @@ public class IndexUpgradeTool extends Configured implements Tool {
             }
             LOGGER.info("Disabled data table " + dataTable);
         } else {
-            LOGGER.info( "Data table " + dataTable +" is already disabled");
+            LOGGER.info( "Data table " + dataTable + " is already disabled");
         }
         for (String indexName : indexes) {
             if (admin.isTableEnabled(TableName.valueOf(indexName))) {
@@ -578,7 +582,7 @@ public class IndexUpgradeTool extends Configured implements Tool {
                 }
                 LOGGER.info("Disabled index table " + indexName);
             } else {
-                LOGGER.info( "Index table " + indexName +" is already disabled");
+                LOGGER.info( "Index table " + indexName + " is already disabled");
             }
         }
     }
@@ -642,84 +646,81 @@ public class IndexUpgradeTool extends Configured implements Tool {
                 LOGGER.info("No indexes to rebuild for table " + dataTableFullName);
                 return;
             }
-
             if(!test) {
                 indexingTool = new IndexTool();
                 indexingTool.setConf(conf);
             }
-
             startIndexRebuilds(rebuildMap, indexingTool);
-
         } catch (SQLException e) {
             LOGGER.severe("Failed to prepare the map for index rebuilds " + e);
-            throw new RuntimeException("Failed to prepare the map for index rebuilds, "
-                    + "manually rebuild the indexes");
+            throw new RuntimeException("Failed to prepare the map for index rebuilds");
         }
     }
 
     private void modifyDataTable(Admin admin, String tableName)
             throws IOException {
-        HTableDescriptor tableDesc = admin.getTableDescriptor(TableName.valueOf(tableName));
+        TableDescriptorBuilder tableDescBuilder = TableDescriptorBuilder
+                .newBuilder(admin.getDescriptor(TableName.valueOf(tableName)));
         if (upgrade) {
-            removeCoprocessor(admin, tableName, tableDesc, Indexer.class.getName());
-            addCoprocessor(admin, tableName,  tableDesc, IndexRegionObserver.class.getName());
+            removeCoprocessor(admin, tableName, tableDescBuilder, Indexer.class.getName());
+            addCoprocessor(admin, tableName,  tableDescBuilder, IndexRegionObserver.class.getName());
         } else {
-            removeCoprocessor(admin, tableName,  tableDesc, IndexRegionObserver.class.getName());
-            addCoprocessor(admin, tableName,  tableDesc, Indexer.class.getName());
+            removeCoprocessor(admin, tableName,  tableDescBuilder, IndexRegionObserver.class.getName());
+            addCoprocessor(admin, tableName,  tableDescBuilder, Indexer.class.getName());
         }
         if (!dryRun) {
-            admin.modifyTable(TableName.valueOf(tableName), tableDesc);
+            admin.modifyTable(tableDescBuilder.build());
         }
     }
 
-    private void addCoprocessor(Admin admin, String tableName, HTableDescriptor tableDesc,
+    private void addCoprocessor(Admin admin, String tableName, TableDescriptorBuilder tableDescBuilder,
                                 String coprocName) throws IOException {
-        addCoprocessor(admin, tableName, tableDesc, coprocName,
+        addCoprocessor(admin, tableName, tableDescBuilder, coprocName,
             QueryServicesOptions.DEFAULT_COPROCESSOR_PRIORITY, prop);
     }
 
-    private void addCoprocessor(Admin admin, String tableName, HTableDescriptor tableDesc,
-            String coprocName, int priority, Map<String, String> propsToAdd) throws IOException {
-        if (!admin.getTableDescriptor(TableName.valueOf(tableName)).hasCoprocessor(coprocName)) {
+    private void addCoprocessor(Admin admin, String tableName, TableDescriptorBuilder tableDescBuilder,
+            String coprocName,int priority, Map<String, String> propsToAdd) throws IOException {
+        if (!admin.getDescriptor(TableName.valueOf(tableName)).hasCoprocessor(coprocName)) {
             if (!dryRun) {
-                tableDesc.addCoprocessor(coprocName,
-                        null, priority, propsToAdd);
+                CoprocessorDescriptorBuilder coprocBuilder =
+                    CoprocessorDescriptorBuilder.newBuilder(coprocName);
+                coprocBuilder.setPriority(priority).setProperties(propsToAdd);
+                tableDescBuilder.setCoprocessor(coprocBuilder.build());
             }
             LOGGER.info("Loaded " + coprocName + " coprocessor on table " + tableName);
         } else {
-            LOGGER.info(coprocName + " coprocessor on table " + tableName
-                    + " is already loaded");
+            LOGGER.info(coprocName + " coprocessor on table " + tableName + "is already loaded");
         }
     }
 
-    private void removeCoprocessor(Admin admin, String tableName, HTableDescriptor tableDesc,
+    private void removeCoprocessor(Admin admin, String tableName, TableDescriptorBuilder tableDescBuilder,
             String coprocName) throws IOException {
-        if (admin.getTableDescriptor(TableName.valueOf(tableName)).hasCoprocessor(coprocName)) {
+        if (admin.getDescriptor(TableName.valueOf(tableName)).hasCoprocessor(coprocName)) {
             if (!dryRun) {
-                tableDesc.removeCoprocessor(coprocName);
+                tableDescBuilder.removeCoprocessor(coprocName);
             }
             LOGGER.info("Unloaded "+ coprocName +"coprocessor on table " + tableName);
         } else {
-            LOGGER.info(coprocName + " coprocessor on table " + tableName
-                    + " is already unloaded");
+            LOGGER.info(coprocName + " coprocessor on table " + tableName + " is already unloaded");
         }
     }
 
     private void modifyIndexTable(Admin admin, HashSet<String> indexes)
             throws IOException {
         for (String indexName : indexes) {
-            HTableDescriptor indexTableDesc = admin.getTableDescriptor(TableName.valueOf(indexName));
+            TableDescriptorBuilder indexTableDescBuilder = TableDescriptorBuilder
+                    .newBuilder(admin.getDescriptor(TableName.valueOf(indexName)));
             if (upgrade) {
                 //GlobalIndexChecker needs to be a "lower" priority than all the others so that it
                 //goes first. It also doesn't get the codec props the IndexRegionObserver needs
-                addCoprocessor(admin, indexName, indexTableDesc, GlobalIndexChecker.class.getName(),
+                addCoprocessor(admin, indexName, indexTableDescBuilder, GlobalIndexChecker.class.getName(),
                     QueryServicesOptions.DEFAULT_COPROCESSOR_PRIORITY -1, emptyProp);
             } else {
-                removeCoprocessor(admin, indexName, indexTableDesc,
-                        GlobalIndexChecker.class.getName());
+                removeCoprocessor(admin, indexName, indexTableDescBuilder, GlobalIndexChecker.class.getName());
             }
             if (!dryRun) {
-                admin.modifyTable(TableName.valueOf(indexName),indexTableDesc);
+                admin.modifyTable(indexTableDescBuilder.build());
             }
         }
     }
@@ -739,7 +740,7 @@ public class IndexUpgradeTool extends Configured implements Tool {
                     + UUID.randomUUID().toString();
             String[] args = getIndexToolArgValues(schema, baseTable, indexName, outFile, tenantId);
             try {
-                LOGGER.info("Rebuilding index: " + StringUtils.join( args,","));
+                LOGGER.info("Rebuilding index: " + String.join(",", args));
                 if (!dryRun) {
                     indexingTool.run(args);
                 }
@@ -814,10 +815,11 @@ public class IndexUpgradeTool extends Configured implements Tool {
         HashMap<String, IndexInfo> indexInfos = new HashMap<>();
         HashSet<String> physicalIndexes = tablesAndIndexes.get(dataTableFullName);
 
+        String viewIndexPhysicalName = MetaDataUtil
+                .getViewIndexPhysicalName(dataTableFullName);
+        boolean hasViewIndex =  physicalIndexes.contains(viewIndexPhysicalName);
         String schemaName = SchemaUtil.getSchemaNameFromFullName(dataTableFullName);
         String tableName = SchemaUtil.getTableNameFromFullName(dataTableFullName);
-        String viewIndexPhysicalName = MetaDataUtil.getViewIndexPhysicalName(dataTableFullName);
-        boolean hasViewIndex =  physicalIndexes.contains(viewIndexPhysicalName);
 
         for (String physicalIndexName : physicalIndexes) {
             if (physicalIndexName.equals(viewIndexPhysicalName)) {
@@ -846,7 +848,6 @@ public class IndexUpgradeTool extends Configured implements Tool {
                 }
             }
         }
-
         return indexInfos;
     }
 
