@@ -39,33 +39,32 @@ import java.util.ListIterator;
 import java.util.Map;
 import java.util.concurrent.TimeUnit;
 
-import com.google.common.cache.Cache;
-import com.google.common.cache.CacheBuilder;
+import org.apache.phoenix.thirdparty.com.google.common.cache.Cache;
+import org.apache.phoenix.thirdparty.com.google.common.cache.CacheBuilder;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.HRegionLocation;
-import org.apache.hadoop.hbase.HTableDescriptor;
-import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Durability;
 import org.apache.hadoop.hbase.client.Get;
-import org.apache.hadoop.hbase.client.HTableInterface;
 import org.apache.hadoop.hbase.client.Increment;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.client.coprocessor.Batch;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
-import org.apache.hadoop.hbase.ipc.BlockingRpcCallback;
+import org.apache.hadoop.hbase.ipc.CoprocessorRpcUtils.BlockingRpcCallback;
 import org.apache.hadoop.hbase.ipc.ServerRpcController;
 import org.apache.hadoop.hbase.protobuf.generated.ClientProtos.MutationProto;
 import org.apache.hadoop.hbase.regionserver.Region;
 import org.apache.hadoop.hbase.regionserver.Store;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.io.WritableUtils;
+import org.apache.phoenix.compat.hbase.OffsetCell;
 import org.apache.phoenix.compile.ColumnResolver;
 import org.apache.phoenix.compile.FromCompiler;
 import org.apache.phoenix.compile.IndexStatementRewriter;
@@ -129,14 +128,14 @@ import org.apache.phoenix.schema.types.PVarbinary;
 import org.apache.phoenix.schema.types.PVarchar;
 import org.apache.phoenix.transaction.PhoenixTransactionProvider.Feature;
 
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 public class IndexUtil {
-
     public static final String INDEX_COLUMN_NAME_SEP = ":";
     public static final byte[] INDEX_COLUMN_NAME_SEP_BYTES = Bytes.toBytes(INDEX_COLUMN_NAME_SEP);
 
-    private static Cache<String, Boolean> indexNameGlobalIndexCheckerEnabledMap = CacheBuilder.newBuilder()
+    private final static Cache<String, Boolean> indexNameGlobalIndexCheckerEnabledMap =
+        CacheBuilder.newBuilder()
             .expireAfterWrite(QueryServicesOptions.GLOBAL_INDEX_CHECKER_ENABLED_MAP_EXPIRATION_MIN,
                     TimeUnit.MINUTES)
             .build();
@@ -308,7 +307,7 @@ public class IndexUtil {
 
         boolean result = false;
         try {
-            HTableDescriptor desc = connection.getQueryServices().getTableDescriptor(index.getBytes());
+            TableDescriptor desc = connection.getQueryServices().getTableDescriptor(index.getBytes());
 
             if (desc != null) {
                 if (desc.hasCoprocessor(GlobalIndexChecker.class.getName())) {
@@ -377,8 +376,8 @@ public class IndexUtil {
                     byte[] regionEndkey = null;
                     if(maintainer.isLocalIndex()) {
                         HRegionLocation tableRegionLocation = connection.getQueryServices().getTableRegionLocation(table.getPhysicalName().getBytes(), dataMutation.getRow());
-                        regionStartKey = tableRegionLocation.getRegionInfo().getStartKey();
-                        regionEndkey = tableRegionLocation.getRegionInfo().getEndKey();
+                        regionStartKey = tableRegionLocation.getRegion().getStartKey();
+                        regionEndkey = tableRegionLocation.getRegion().getEndKey();
                     }
                     indexMutations.add(maintainer.buildUpdateMutation(kvBuilder, valueGetter, ptr, ts, regionStartKey, regionEndkey));
                 }
@@ -569,11 +568,11 @@ public class IndexUtil {
                 joinResult = dataRegion.get(get);
             } else {
                 TableName dataTable =
-                        TableName.valueOf(MetaDataUtil.getLocalIndexUserTableName(
-                            environment.getRegion().getTableDesc().getNameAsString()));
-                HTableInterface table = null;
+                    TableName.valueOf(MetaDataUtil.getLocalIndexUserTableName(environment.getRegion().
+                        getTableDescriptor().getTableName().getNameAsString()));
+                Table table = null;
                 try {
-                    table = environment.getTable(dataTable);
+                    table = environment.getConnection().getTable(dataTable);
                     joinResult = table.get(get);
                 } finally {
                     if (table != null) table.close();
@@ -587,8 +586,9 @@ public class IndexUtil {
             byte[] value =
                     tupleProjector.getSchema().toBytes(joinTuple, tupleProjector.getExpressions(),
                         tupleProjector.getValueBitSet(), ptr);
-            KeyValue keyValue =
-                    KeyValueUtil.newKeyValue(firstCell.getRowArray(),firstCell.getRowOffset(),firstCell.getRowLength(), VALUE_COLUMN_FAMILY,
+            Cell keyValue =
+                    PhoenixKeyValueUtil.newKeyValue(firstCell.getRowArray(),
+                        firstCell.getRowOffset(),firstCell.getRowLength(), VALUE_COLUMN_FAMILY,
                         VALUE_COLUMN_QUALIFIER, firstCell.getTimestamp(), value, 0, value.length);
             result.add(keyValue);
         }
@@ -597,122 +597,7 @@ public class IndexUtil {
         while (itr.hasNext()) {
             final Cell cell = itr.next();
             // TODO: Create DelegateCell class instead
-            Cell newCell = new Cell() {
-
-                @Override
-                public byte[] getRowArray() {
-                    return cell.getRowArray();
-                }
-
-                @Override
-                public int getRowOffset() {
-                    return cell.getRowOffset() + offset;
-                }
-
-                @Override
-                public short getRowLength() {
-                    return (short) (cell.getRowLength() - offset);
-                }
-
-                @Override
-                public byte[] getFamilyArray() {
-                    return cell.getFamilyArray();
-                }
-
-                @Override
-                public int getFamilyOffset() {
-                    return cell.getFamilyOffset();
-                }
-
-                @Override
-                public byte getFamilyLength() {
-                    return cell.getFamilyLength();
-                }
-
-                @Override
-                public byte[] getQualifierArray() {
-                    return cell.getQualifierArray();
-                }
-
-                @Override
-                public int getQualifierOffset() {
-                    return cell.getQualifierOffset();
-                }
-
-                @Override
-                public int getQualifierLength() {
-                    return cell.getQualifierLength();
-                }
-
-                @Override
-                public long getTimestamp() {
-                    return cell.getTimestamp();
-                }
-
-                @Override
-                public byte getTypeByte() {
-                    return cell.getTypeByte();
-                }
-
-                @Override
-                public long getMvccVersion() {
-                    return cell.getMvccVersion();
-                }
-
-                @Override public long getSequenceId() {
-                    return cell.getSequenceId();
-                }
-
-                @Override
-                public byte[] getValueArray() {
-                    return cell.getValueArray();
-                }
-
-                @Override
-                public int getValueOffset() {
-                    return cell.getValueOffset();
-                }
-
-                @Override
-                public int getValueLength() {
-                    return cell.getValueLength();
-                }
-
-                @Override
-                public byte[] getTagsArray() {
-                    return cell.getTagsArray();
-                }
-
-                @Override
-                public int getTagsOffset() {
-                    return cell.getTagsOffset();
-                }
-
-                @Override
-                public int getTagsLength() {
-                    return cell.getTagsLength();
-                }
-
-                @Override
-                public byte[] getValue() {
-                    return cell.getValue();
-                }
-
-                @Override
-                public byte[] getFamily() {
-                    return cell.getFamily();
-                }
-
-                @Override
-                public byte[] getQualifier() {
-                    return cell.getQualifier();
-                }
-
-                @Override
-                public byte[] getRow() {
-                    return cell.getRow();
-                }
-            };
+            Cell newCell = new OffsetCell(cell, offset);
             itr.set(newCell);
         }
     }
@@ -749,18 +634,17 @@ public class IndexUtil {
             }
         }
         region.batchMutate(
-            mutations.toArray(new Mutation[mutations.size()]),
-            HConstants.NO_NONCE, HConstants.NO_NONCE);
+            mutations.toArray(new Mutation[mutations.size()]));
     }
     
     public static MetaDataMutationResult updateIndexState(String indexTableName, long minTimeStamp,
-            HTableInterface metaTable, PIndexState newState) throws Throwable {
+            Table metaTable, PIndexState newState) throws Throwable {
         byte[] indexTableKey = SchemaUtil.getTableKeyFromFullName(indexTableName);
         return updateIndexState(indexTableKey, minTimeStamp, metaTable, newState);
     }
     
     public static MetaDataMutationResult updateIndexState(byte[] indexTableKey, long minTimeStamp,
-            HTableInterface metaTable, PIndexState newState) throws Throwable {
+            Table metaTable, PIndexState newState) throws Throwable {
         // Mimic the Put that gets generated by the client on an update of the index state
         Put put = new Put(indexTableKey);
         put.addColumn(PhoenixDatabaseMetaData.TABLE_FAMILY_BYTES, PhoenixDatabaseMetaData.INDEX_STATE_BYTES,
@@ -776,7 +660,7 @@ public class IndexUtil {
                     @Override
                     public MetaDataResponse call(MetaDataService instance) throws IOException {
                         ServerRpcController controller = new ServerRpcController();
-                        BlockingRpcCallback<MetaDataResponse> rpcCallback = new BlockingRpcCallback<MetaDataResponse>();
+                        BlockingRpcCallback<MetaDataResponse> rpcCallback = new BlockingRpcCallback<>();
                         UpdateIndexStateRequest.Builder builder = UpdateIndexStateRequest.newBuilder();
                         for (Mutation m : tableMetadata) {
                             MutationProto mp = ProtobufUtil.toProto(m);
@@ -805,10 +689,10 @@ public class IndexUtil {
     }
 
     public static boolean isLocalIndexStore(Store store) {
-        return store.getFamily().getNameAsString().startsWith(QueryConstants.LOCAL_INDEX_COLUMN_FAMILY_PREFIX);
+        return store.getColumnFamilyDescriptor().getNameAsString().startsWith(QueryConstants.LOCAL_INDEX_COLUMN_FAMILY_PREFIX);
     }
     
-    public static PTable getPDataTable(Connection conn, HTableDescriptor tableDesc) throws SQLException {
+    public static PTable getPDataTable(Connection conn, TableDescriptor tableDesc) throws SQLException {
         String dataTableName = Bytes.toString(tableDesc.getValue(MetaDataUtil.DATA_TABLE_NAME_PROP_BYTES));
         String physicalTableName = tableDesc.getTableName().getNameAsString();
         PTable pDataTable = null;
