@@ -17,13 +17,32 @@
  */
 package org.apache.phoenix.util;
 
-import com.google.common.collect.Iterators;
-import com.google.common.collect.Lists;
+import static org.apache.phoenix.compile.OrderByCompiler.OrderBy.FWD_ROW_KEY_ORDER_BY;
+import static org.apache.phoenix.compile.OrderByCompiler.OrderBy.REV_ROW_KEY_ORDER_BY;
+import static org.apache.phoenix.coprocessor.BaseScannerRegionObserver.CUSTOM_ANNOTATIONS;
+import static org.apache.phoenix.coprocessor.BaseScannerRegionObserver.SCAN_ACTUAL_START_ROW;
+import static org.apache.phoenix.coprocessor.BaseScannerRegionObserver.SCAN_START_ROW_SUFFIX;
+import static org.apache.phoenix.coprocessor.BaseScannerRegionObserver.SCAN_STOP_ROW_SUFFIX;
+import static org.apache.phoenix.query.QueryConstants.ENCODED_EMPTY_COLUMN_NAME;
+import static org.apache.phoenix.schema.types.PDataType.TRUE_BYTES;
+import static org.apache.phoenix.util.ByteUtil.EMPTY_BYTE_ARRAY;
+
+import java.io.IOException;
+import java.sql.SQLException;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Collections;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.NavigableSet;
+import java.util.TreeMap;
+
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.HRegionInfo;
 import org.apache.hadoop.hbase.client.Mutation;
+import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.filter.Filter;
@@ -78,26 +97,8 @@ import org.apache.phoenix.schema.types.PVarbinary;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.io.IOException;
-import java.sql.SQLException;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collections;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
-import java.util.NavigableSet;
-import java.util.TreeMap;
-
-import static org.apache.phoenix.compile.OrderByCompiler.OrderBy.FWD_ROW_KEY_ORDER_BY;
-import static org.apache.phoenix.compile.OrderByCompiler.OrderBy.REV_ROW_KEY_ORDER_BY;
-import static org.apache.phoenix.coprocessor.BaseScannerRegionObserver.CUSTOM_ANNOTATIONS;
-import static org.apache.phoenix.coprocessor.BaseScannerRegionObserver.SCAN_ACTUAL_START_ROW;
-import static org.apache.phoenix.coprocessor.BaseScannerRegionObserver.SCAN_START_ROW_SUFFIX;
-import static org.apache.phoenix.coprocessor.BaseScannerRegionObserver.SCAN_STOP_ROW_SUFFIX;
-import static org.apache.phoenix.query.QueryConstants.ENCODED_EMPTY_COLUMN_NAME;
-import static org.apache.phoenix.schema.types.PDataType.TRUE_BYTES;
-import static org.apache.phoenix.util.ByteUtil.EMPTY_BYTE_ARRAY;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Iterators;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 /**
  * 
@@ -179,19 +180,12 @@ public class ScanUtil {
             newScan.setFamilyMap(clonedMap);
             // Carry over the reversed attribute
             newScan.setReversed(scan.isReversed());
-            if (scan.isSmall()) {
-                // HBASE-25644 : Only if Scan#setSmall(boolean) is called with
-                // true, readType should be set PREAD. For non-small scan,
-                // setting setSmall(false) is redundant and degrades perf
-                // without HBASE-25644 fix.
-                newScan.setSmall(true);
-            }
+            newScan.setSmall(scan.isSmall());
             return newScan;
         } catch (IOException e) {
             throw new RuntimeException(e);
         }
     }
-
     /**
      * Intersects the scan start/stop row with the startKey and stopKey
      * @param scan
@@ -696,8 +690,7 @@ public class ScanUtil {
     }
 
     /**
-     * Start key and stop key of the original scan from client are regions start and end keys so
-     * prefix scan start/stop key to the start row/stop row suffix and set them as scan boundaries.
+     * prefix region start key to the start row/stop row suffix and set as scan boundaries.
      * @param scan
      */
     public static void setupLocalIndexScan(Scan scan) {
@@ -711,7 +704,7 @@ public class ScanUtil {
         }
     }
 
-    public static byte[] getActualStartRow(Scan localIndexScan, HRegionInfo regionInfo) {
+    public static byte[] getActualStartRow(Scan localIndexScan, RegionInfo regionInfo) {
         return localIndexScan.getAttribute(SCAN_START_ROW_SUFFIX) == null ? localIndexScan
                 .getStartRow() : ScanRanges.prefixKey(localIndexScan.getAttribute(SCAN_START_ROW_SUFFIX), 0 ,
             regionInfo.getStartKey().length == 0 ? new byte[regionInfo.getEndKey().length]
@@ -1237,7 +1230,7 @@ public class ScanUtil {
 
     public static void getDummyResult(byte[] rowKey, List<Cell> result) {
         Cell keyValue =
-                KeyValueUtil.newKeyValue(rowKey, 0,
+                PhoenixKeyValueUtil.newKeyValue(rowKey, 0,
                         rowKey.length, EMPTY_BYTE_ARRAY, EMPTY_BYTE_ARRAY,
                         0, EMPTY_BYTE_ARRAY, 0, EMPTY_BYTE_ARRAY.length);
         result.add(keyValue);
