@@ -120,20 +120,20 @@ import org.apache.hadoop.hbase.HBaseConfiguration;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.HRegionInfo;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.IntegrationTestingUtility;
 import org.apache.hadoop.hbase.MiniHBaseCluster;
 import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
+import org.apache.hadoop.hbase.client.RegionInfo;
+import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.ipc.PhoenixRpcSchedulerFactory;
-import org.apache.hadoop.hbase.master.AssignmentManager;
 import org.apache.hadoop.hbase.master.HMaster;
+import org.apache.hadoop.hbase.master.assignment.AssignmentManager;
+import org.apache.hadoop.hbase.regionserver.HRegion;
 import org.apache.hadoop.hbase.regionserver.HRegionServer;
 import org.apache.hadoop.hbase.regionserver.RSRpcServices;
 import org.apache.hadoop.hbase.util.Bytes;
-import org.apache.hadoop.hbase.util.JVMClusterUtil.RegionServerThread;
 import org.apache.phoenix.SystemExitRule;
 import org.apache.phoenix.compat.hbase.CompatUtil;
 import org.apache.phoenix.end2end.NeedsOwnMiniClusterTest;
@@ -158,18 +158,18 @@ import org.apache.phoenix.util.PropertiesUtil;
 import org.apache.phoenix.util.QueryUtil;
 import org.apache.phoenix.util.ReadOnlyProps;
 import org.apache.phoenix.util.SchemaUtil;
-import org.apache.phoenix.util.TestUtil;
 import org.apache.phoenix.util.ServerUtil.ConnectionFactory;
+import org.apache.phoenix.util.TestUtil;
 import org.junit.ClassRule;
 import org.junit.rules.TemporaryFolder;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.collect.ImmutableMap;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
-import com.google.common.collect.Sets;
-import com.google.common.util.concurrent.ThreadFactoryBuilder;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableMap;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
+import org.apache.phoenix.thirdparty.com.google.common.util.concurrent.ThreadFactoryBuilder;
 
 /**
  * 
@@ -618,6 +618,7 @@ public abstract class BaseTest {
         conf.setInt("ipc.server.read.threadpool.size", 2);
         conf.setInt("ipc.server.handler.threadpool.size", 2);
         conf.setInt("hbase.regionserver.hlog.syncer.count", 2);
+        conf.setInt("hbase.hfile.compaction.discharger.interval", 5000);
         conf.setInt("hbase.hlog.asyncer.number", 2);
         conf.setInt("hbase.assignment.zkevent.workers", 5);
         conf.setInt("hbase.assignment.threads.max", 5);
@@ -1562,11 +1563,11 @@ public abstract class BaseTest {
      */
     protected static synchronized void disableAndDropNonSystemTables() throws Exception {
         if (driver == null) return;
-        HBaseAdmin admin = driver.getConnectionQueryServices(null, null).getAdmin();
+        Admin admin = driver.getConnectionQueryServices(null, null).getAdmin();
         try {
-            HTableDescriptor[] tables = admin.listTables();
-            for (HTableDescriptor table : tables) {
-                String schemaName = SchemaUtil.getSchemaNameFromFullName(table.getName());
+            TableDescriptor[] tables = admin.listTables();
+            for (TableDescriptor table : tables) {
+                String schemaName = SchemaUtil.getSchemaNameFromFullName(table.getTableName().getName());
                 if (!QueryConstants.SYSTEM_SCHEMA_NAME.equals(schemaName)) {
                     disableAndDropTable(admin, table.getTableName());
                 }
@@ -1576,7 +1577,6 @@ public abstract class BaseTest {
         }
     }
     
-
     private static synchronized void disableAndDropTable(final Admin admin, final TableName tableName)
             throws Exception {
         Future<Void> future = null;
@@ -1612,17 +1612,17 @@ public abstract class BaseTest {
 
     private static synchronized void disableAndDropAllTables() throws IOException {
         long startTime = System.currentTimeMillis();
-        final Admin admin = utility.getHBaseAdmin();
+        Admin admin = utility.getAdmin();
         ExecutorService dropHTableExecutor = Executors
                 .newCachedThreadPool(factory);
 
-        List<HTableDescriptor> tableDescriptors = Arrays.asList(admin.listTables());
+        List<TableDescriptor> tableDescriptors = admin.listTableDescriptors();
         int tableCount = tableDescriptors.size();
 
         int retryCount=10;
         List<Future<Void>> futures = new ArrayList<>();
         while (!tableDescriptors.isEmpty() && retryCount-->0) {
-            for(final HTableDescriptor tableDescriptor : tableDescriptors) {
+            for(TableDescriptor tableDescriptor : tableDescriptors) {
                 futures.add(dropHTableExecutor.submit(new Callable<Void>() {
                     @Override
                     public Void call() throws Exception {
@@ -1641,7 +1641,7 @@ public abstract class BaseTest {
                     LOGGER.warn("Error while dropping table, will try again", e);
                 }
             }
-            tableDescriptors = Arrays.asList(admin.listTables());
+            tableDescriptors = admin.listTableDescriptors();
         }
         if(!tableDescriptors.isEmpty()) {
            LOGGER.error("Could not clean up tables!");
@@ -1859,20 +1859,35 @@ public abstract class BaseTest {
         }
         phxConn.close();
     }
-    
 
     /**
      *  Synchronously split table at the given split point
      */
-    protected static void splitRegion(TableName fullTableName, byte[] splitPoint) throws SQLException, IOException, InterruptedException {
-         HBaseAdmin admin =
-                driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
-        admin.split(fullTableName, splitPoint);
-        // make sure the split finishes (there's no synchronous splitting before HBase 2.x)
-        admin.disableTable(fullTableName);
-        admin.enableTable(fullTableName);
+    protected static void splitTableSync(Admin admin, TableName hbaseTableName, byte[] splitPoint,
+            int expectedRegions) throws IOException, InterruptedException {
+        admin.split(hbaseTableName, splitPoint);
+        for (int i = 0; i < 30; i++) {
+            List<HRegion> regions = getUtility().getHBaseCluster().getRegions(hbaseTableName);
+            if (regions.size() >= expectedRegions) {
+                boolean splitSuccessful = true;
+                for (HRegion region : regions) {
+                    if (!region.isSplittable()) {
+                        splitSuccessful = false;
+                    }
+                }
+                if(splitSuccessful) {
+                    return;
+                }
+            }
+            LOGGER.info(
+                "Sleeping for 1000 ms while waiting for {} to split and all regions to come online",
+                hbaseTableName.getNameAsString());
+            Thread.sleep(1000);
+        }
+        throw new IOException("Split did not succeed for table: " + hbaseTableName.getNameAsString()
+                + " , expected regions after split: " + expectedRegions);
     }
-    
+
     /**
      * Returns true if the region contains atleast one of the metadata rows we are interested in
      */
@@ -1887,7 +1902,7 @@ public abstract class BaseTest {
     }
 
     protected static void splitTable(TableName fullTableName, List<byte[]> splitPoints) throws Exception {
-        HBaseAdmin admin =
+        Admin admin =
                 driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
         assertTrue("Needs at least two split points ", splitPoints.size() > 1);
         assertTrue(
@@ -1901,8 +1916,10 @@ public abstract class BaseTest {
         AssignmentManager am = master.getAssignmentManager();
         // No need to split on the first splitPoint since the end key of region boundaries are exclusive
         for (int i=1; i<splitPoints.size(); ++i) {
-            splitRegion(fullTableName, splitPoints.get(i));
+            splitTableSync(admin, fullTableName, splitPoints.get(i), i + 1);
         }
+        List<RegionInfo> regionInfoList = admin.getRegions(fullTableName);
+        assertEquals(splitPoints.size(), regionInfoList.size());
         HashMap<ServerName, List<HRegionInfo>> serverToRegionsList = Maps.newHashMapWithExpectedSize(NUM_SLAVES_BASE);
         Deque<ServerName> availableRegionServers = new ArrayDeque<ServerName>(NUM_SLAVES_BASE);
         for (int i=0; i<NUM_SLAVES_BASE; ++i) {
@@ -1975,42 +1992,24 @@ public abstract class BaseTest {
 
         splitTable(PhoenixDatabaseMetaData.SYSTEM_CATALOG_HBASE_TABLE_NAME, splitPoints);
     }
-
-    // We don't need need this for 1.4+, but this works with 1.3, 1.4, and 1.5
-    private static int getRegionServerIndex(MiniHBaseCluster cluster, ServerName serverName) {
-        // we have a small number of region servers, this should be fine for now.
-        List<RegionServerThread> servers = cluster.getRegionServerThreads();
-        for (int i = 0; i < servers.size(); i++) {
-            if (servers.get(i).getRegionServer().getServerName().equals(serverName)) {
-                return i;
-            }
-        }
-        return -1;
-    }
-
+    
     /**
      * Ensures each region of SYSTEM.CATALOG is on a different region server
      */
     private static void moveRegion(HRegionInfo regionInfo, ServerName srcServerName, ServerName dstServerName) throws Exception  {
-        HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
+        Admin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
         HBaseTestingUtility util = getUtility();
         MiniHBaseCluster cluster = util.getHBaseCluster();
         HMaster master = cluster.getMaster();
         AssignmentManager am = master.getAssignmentManager();
-
-        // The 1.4+ MiniCluster way
-        // HRegionServer dstServer = util.getHBaseCluster().getRegionServer(dstServerName);
-        // HRegionServer srcServer = util.getHBaseCluster().getRegionServer(srcServerName);
-        HRegionServer dstServer =
-                cluster.getRegionServer(getRegionServerIndex(cluster, dstServerName));
-        HRegionServer srcServer =
-                cluster.getRegionServer(getRegionServerIndex(cluster, srcServerName));
+   
+        HRegionServer dstServer = util.getHBaseCluster().getRegionServer(dstServerName);
+        HRegionServer srcServer = util.getHBaseCluster().getRegionServer(srcServerName);
         byte[] encodedRegionNameInBytes = regionInfo.getEncodedNameAsBytes();
         admin.move(encodedRegionNameInBytes, Bytes.toBytes(dstServer.getServerName().getServerName()));
         while (dstServer.getOnlineRegion(regionInfo.getRegionName()) == null
                 || dstServer.getRegionsInTransitionInRS().containsKey(encodedRegionNameInBytes)
-                || srcServer.getRegionsInTransitionInRS().containsKey(encodedRegionNameInBytes)
-                || master.getAssignmentManager().getRegionStates().isRegionsInTransition()) {
+                || srcServer.getRegionsInTransitionInRS().containsKey(encodedRegionNameInBytes)) {
             // wait for the move to be finished
             Thread.sleep(100);
         }
@@ -2026,10 +2025,11 @@ public abstract class BaseTest {
             @Override
             public void run() {
                     try {
-                        final HBaseAdmin admin = utility.getHBaseAdmin();
-                        final HRegionInfo tableRegion =
-                                admin.getTableRegions(TableName.valueOf(tableName)).get(0);
-                        admin.unassign(tableRegion.getRegionName(), false);
+                        final Admin admin = utility.getAdmin();
+                        final RegionInfo tableRegion =
+                                admin.getRegions(TableName.valueOf(tableName)).get(0);
+                        admin.unassign(tableRegion.getEncodedNameAsBytes(), false);
+                        admin.assign(tableRegion.getEncodedNameAsBytes());
                     } catch (IOException e) {
                         e.printStackTrace();
                     }
@@ -2043,11 +2043,13 @@ public abstract class BaseTest {
      * Confirms that no storeFile under any region has refCount leakage
      *
      * @return true if any region has refCount leakage
+     * @throws IOException caused by
+     *     {@link CompatUtil#isAnyStoreRefCountLeaked(Admin)}
      */
-    protected synchronized static boolean isAnyStoreRefCountLeaked() {
+    protected synchronized static boolean isAnyStoreRefCountLeaked()
+            throws IOException {
         if (getUtility() != null) {
-            return CompatUtil.isAnyStoreRefCountLeaked(getUtility()
-                .getHBaseCluster().getMaster());
+            return CompatUtil.isAnyStoreRefCountLeaked(getUtility().getAdmin());
         }
         return false;
     }
