@@ -17,9 +17,13 @@
  */
 package org.apache.phoenix.compat.hbase;
 
+import java.io.IOException;
+
+import org.apache.hadoop.hbase.client.RowMutations;
 import org.apache.hadoop.hbase.client.Table;
 
 public abstract class CompatDelegateHTable implements Table {
+
     protected final Table delegate;
 
     public CompatDelegateHTable(Table delegate) {
@@ -27,22 +31,7 @@ public abstract class CompatDelegateHTable implements Table {
     }
 
     @Override
-    public int getReadRpcTimeout() {
-        return delegate.getReadRpcTimeout();
-    }
-
-    @Override
-    public void setReadRpcTimeout(int readRpcTimeout) {
-        delegate.setReadRpcTimeout(readRpcTimeout);
-    }
-
-    @Override
-    public int getWriteRpcTimeout() {
-        return delegate.getWriteRpcTimeout();
-    }
-
-    @Override
-    public void setWriteRpcTimeout(int writeRpcTimeout) {
-        delegate.setWriteRpcTimeout(writeRpcTimeout);
+    public void mutateRow(RowMutations rm) throws IOException {
+        delegate.mutateRow(rm);
     }
 }
