@@ -24,7 +24,7 @@ import java.util.Collection;
 import java.util.List;
 import java.util.Properties;
 
-import com.google.common.annotations.VisibleForTesting;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.CommandLine;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.CommandLineParser;
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.HelpFormatter;
@@ -142,7 +142,6 @@ public class Pherf {
                         command.getOptionValue("monitorFrequency") :
                         properties.getProperty("pherf.default.monitorFrequency");
         properties.setProperty("pherf.default.monitorFrequency", monitorFrequency);
-
         LOGGER.debug("Using Monitor: " + monitor);
         LOGGER.debug("Monitor Frequency Ms:" + monitorFrequency);
         properties.setProperty(PherfConstants.LOG_PER_NROWS_NAME, getLogPerNRow(command));
@@ -201,10 +200,10 @@ public class Pherf {
         try {
             String logPerNRows = (command.hasOption("log_per_nrows")) ?
                     command.getOptionValue("log_per_nrows") :
-                    properties.getProperty(
-                            PherfConstants.LOG_PER_NROWS_NAME,
-                            String.valueOf(PherfConstants.LOG_PER_NROWS)
-                    );
+                        properties.getProperty(
+                                PherfConstants.LOG_PER_NROWS_NAME,
+                                String.valueOf(PherfConstants.LOG_PER_NROWS)
+                        );
             if (Integer.valueOf(logPerNRows) > 0) {
                 return logPerNRows;
             }
